/***********************************************************************************/
/*      Copyright (C)           ABB  (2003). All Rights Reserved                   */
/*      Product:                ABB 2600T-263/265 Profibus PA                      */
/*                                                                                 */
/*      Device:                 ABB 2600T-263/265 PRESSURE DEVICE for PROFIBUS PA  */
/*      Description:            Device Description                                 */
/*      Dictionary:             PDMTO2600-PA.dct, SIPADC01.dct                     */
/*                                                                                 */
/*  $Revision:   1.01 $                                                            */
/*  $Date:   08.07.2003  $                                                         */
/***********************************************************************************/

MANUFACTURER            0x1A,
DEVICE_TYPE             0x89,
DEVICE_REVISION         0x02,
DD_REVISION             0x01

#define ID_FC_ERROR             3000

#define DEFAULT_MANUFACTURER_ID 26

// @@st Auch SW Versionierung so mglich
#define LARGE_DIAPHRAGM_MAT_CODE (phys_software_rev_HART > 21)

#define DEF_TRANS_PROC_CONN_TYPE                                                          \
                DEFAULT_VALUE   0x00FB;                                                           \
                {       0x0001, [flange_connect_1_4_18_npt]                             },\
                {       0x0002, [process_connect_din19213_1_4_18_npt]   },\
                {       0x0003, [pin_din16288_form_b_g_1_2_a]                   },\
                {       0x0004, [pin_din16288_form_d_g_1_2_a]                   },\
                {       0x0005, [npt_1_2_outside]                                               },\
                {       0x0006, [npt_1_2_inside]                                                },\
                {       0x0007, [npt_1_4_inside]                                                },\
                {       0x0008, [pin_din16288_form]                                             },\
                {       0x0009, [alcatel_flange_dn25]                                   },\
                {       0x000A, [pressure_sensor_with_flange]                   },\
                {       0x00FB, [none_proc_conn]                                                },\
                {       0x00FD, [special_proc_conn]                                             }

#define STATUS_OUTPUT_NO_RCAS                           \
                { 0x20, [status_GOOD_00]                },      \
                { 0x21, [status_GOOD_01]                },      \
                { 0x22, [status_GOOD_02]                },      \
                { 0x23, [status_GOOD_03]                },      \
                { 0x24, [status_GOOD_04]                },      \
                { 0x25, [status_GOOD_05]                },      \
                { 0x26, [status_GOOD_06]                }       \
                { 0x28, [status_GOOD_08]                },      \
                { 0x29, [status_GOOD_09]                },      \
                { 0x10, [status_UNCERTAIN_00]   },      \
                { 0x11, [status_UNCERTAIN_01]   },      \
                { 0x12, [status_UNCERTAIN_02]   },      \
                { 0x13, [status_UNCERTAIN_03]   },      \
                { 0x14, [status_UNCERTAIN_04]   },      \
                { 0x15, [status_UNCERTAIN_05]   },      \
                { 0x16, [status_UNCERTAIN_06]   },      \
                { 0x17, [status_UNCERTAIN_07]   },      \
                { 0x00, [status_BAD_00]                 },      \
                { 0x01, [status_BAD_01]                 },      \
                { 0x02, [status_BAD_02]                 },      \
                { 0x03, [status_BAD_03]                 },      \
                { 0x04, [status_BAD_04]                 },      \
                { 0x05, [status_BAD_05]                 },      \
                { 0x06, [status_BAD_06]                 },      \
                { 0x07, [status_BAD_07]                 }

#define STATUS_OUTPUT_LIMIT                                                     \
                { 0x00, [status_limit_OK]                               },      \
                { 0x01, [status_limit_UNDERFLOW]                },      \
                { 0x02, [status_limit_OVERFLOW]                 },      \
                { 0x03, [status_limit_VALUE_CONSTANT]   }

#define DEF_TRANS_SENS_FILL_FLUID                                         \
                DEFAULT_VALUE   0x00FB;                                           \
                {0x0001,                [siliconoil]                            },\
                {0x0002,                [fluorcarbon]                           },\
                {0x0003,                [dest_water]                            },\
                {0x0004,                [high_temp_oil]                         },\
                {0x0005,                [vegetable_oil]                         },\
                {0x0006,                [mineraloil]                            },\
                {0x0007,                [whiteoil]                                      },\
                {0x0008,                [fill_fluid_fda_certified]      },\
                {0x0009,                [fill_fluid_abb]                        },\
                {0x00FB,                [none_fill_fluid]                       },\
                {0x00FD,                [special_fill_fluid]            }


#define DEF_TRANS_SENSOR_UNIT_CHANGE     \
                {1146,          "inH2O"         },\
                {1155,          "inHg"          },\
                {1152,          "ftH2O"         },\
                {1149,          "mmH2O"         },\
                {1157,          "mmHg"          },\
                {1141,          "psi"           },\
                {1137,          "bar"           },\
                {1138,          "mbar"          },\
                {1144,          "g/cm2"         },\
                {1145,          "kg/cm2"        },\
                {1130,          "Pa"            },\
                {1133,          "kPa"           },\
                {1139,          "torr"          },\
                {1140,          "atm"           },\
                {1342,          "%"                     },\
                {1132,          "MPa"           },\
                {1131,          "GPa"           },\
                {1134,          "mPa"           },\
                {1135,          "uPa"           },\
                {1136,          "hPa"           }


#define DEF_TRANS_SENSOR_TYPE                                             \
                {       0x0012, "MVD Piezo AAI"                                 },\
                {       0x0014, "MVD Kap. 15712"                                },\
                {       0x0016, "MVD Piezo 15712"                               },\
                {       0x0017, "MVDA Piezo 15713"                              },\
                {       0x001C, "MVD Piezo 15712 100 bar"               },\
                {       0x001E, "MVP Kap. 15753"                                },\
                {       0x001F, "MVPA Kap. 15754"                               },\
                {       0x0020, "MVP Piezo 15753"                               },\
                {       0x0021, "MVPA Piezo 15754"                              },\
                {       0x0023, [sondekapazitiversensor]                },\
                {       0x0019, [internaluse]                                   }


#define DEF_TRANS_DIAPHRAGM_MAT \
   IF (LARGE_DIAPHRAGM_MAT_CODE)                                          \
   {  \
                {0x0000,                [carbon_steel]                          },\
                {0x0001,                [stainless_steel_304]           },\
                {0x0002,                [stainless_steel_316]           },\
                {0x0003,                [hastelloy_c]                           },\
                {0x0004,                [monel]                                         },\
                {0x0005,                [tantalum]                                      },\
                {0x0006,                [titanium]                                      },\
                {0x0007,                [pt_ir]                                         },\
                {0x0008,                [alloy_20]                                      },\
                {0x0009,                [co_cr_ni]                                      },\
                {0x000A,                [ptfe]                                          },\
                {0x000B,                [viton]                                         },\
                {0x000C,                [buna_n]                                        },\
                {0x000D,                [ethyl_prop]                            },\
                {0x000E,                [urethane]                                      },\
                {0x000F,                [gold_monel]                            },\
                {0x0010,                [tefzel]                                        },\
                {0x0011,                [ryton]                                         },\
                {0x0012,                [ceramic]                                       },\
                {0x0013,                [stainless_steel_316l]          },\
                {0x0014,                [pvc]                                           },\
                {0x0015,                [nitrile_rubber]                        },\
                {0x0016,                [kalrez]                                        },\
                {0x0017,                [inconel]                                       },\
                {0x0018,                [kynar]                                         },\
                {0x0019,                [aluminium]                                     },\
                {0x001A,                [nickel]                                        },\
                {0x001B,                [fep]                                           },\
                {0x001C,                [stainless_steel_316ti]         },\
                {0x001E,                [hastelloy_c276]                        },\
                {0x001F,                [klinger_c4401]                         },\
                {0x0020,                [thermotork]                            },\
                {0x0021,                [grafoil]                                       },\
                {0x0022,                [ptfe_coated_316l_sst]          },\
                {0x0023,                [gold_plated_hastelloy_c276]},\
                {0x0024,                [ptfe_glass]                            },\
                {0x0025,                [ptfe_graphit]                          },\
                {0x0081,                [stainless_steel_316ti_316l]},\
                {0x0082,                [hastelloy_c276_steel_316ti]},\
                {0x0084,                [stainless_steel_316l_316ti]},\
                {0x0085,                [per_fluor_kautschuk]           },\
                {0x0086,                [stainless_steel_316l_b]        },\
                {0x0087,                [gold_stainless_steel_316l]     },\
                {0x0088,                [gold_plated_monel]                     },\
                {0x0089,                [pvdf]                                          },\
                {0x008A,                [epdm]                                          },\
                {0x0090,                [steel]                                         },\
                {0x0091,                [stainless_steel_ferro]         },\
                {0x0092,                [stainless_steel_austenit]      },\
                {0x0093,                [copper_alloy]                          },\
                {0x0094,                [brass]                                         },\
                {0x00EA,                [ptfe_hastelloy]                        },\
                {0x00EB,                [stainless_steel_cf_8m]         },\
                {0x00EC,                [hastelloy_sst]                         },\
                {0x00ED,                [gold_plated_sst]                       },\
                {0x00EF,                [monel_400]                                     },\
                {0x00FA,                [not_used]                                      },\
                {0x00FB,                [none]                                          },\
                {0x00FC,                [unknown]                                       },\
                {0x00FD,                [special]                                       } \
   }       \
   ELSE    \
   {                                       \
                {0x0000,                [carbon_steel]                          },\
                {0x0001,                [stainless_steel_304]           },\
                {0x0002,                [stainless_steel_316]           },\
                {0x0003,                [hastelloy_c]                           },\
                {0x0004,                [monel]                                         },\
                {0x0005,                [tantalum]                                      },\
                {0x0006,                [titanium]                                      },\
                {0x0007,                [pt_ir]                                         },\
                {0x0008,                [alloy_20]                                      },\
                {0x0009,                [co_cr_ni]                                      },\
                {0x000A,                [ptfe]                                          },\
                {0x000B,                [viton]                                         },\
                {0x000C,                [buna_n]                                        },\
                {0x000D,                [ethyl_prop]                            },\
                {0x000E,                [urethane]                                      },\
                {0x000F,                [gold_monel]                            },\
                {0x0010,                [tefzel]                                        },\
                {0x0011,                [ryton]                                         },\
                {0x0012,                [ceramic]                                       },\
                {0x0013,                [stainless_steel_316l]          },\
                {0x0014,                [pvc]                                           },\
                {0x0015,                [nitrile_rubber]                        },\
                {0x0016,                [kalrez]                                        },\
                {0x0017,                [inconel]                                       },\
                {0x0018,                [kynar]                                         },\
                {0x0019,                [aluminium]                                     },\
                {0x001A,                [nickel]                                        },\
                {0x001B,                [fep]                                           },\
                {0x001C,                [stainless_steel_316ti]         },\
                {0x001E,                [hastelloy_c276]                        },\
                {0x001F,                [klinger_c4401]                         },\
                {0x0020,                [thermotork]                            },\
                {0x0021,                [grafoil]                                       },\
                {0x0022,                [ptfe_coated_316l_sst]          },\
                {0x0023,                [gold_plated_hastelloy_c276]},\
                {0x0024,                [ptfe_glass]                            },\
                {0x0025,                [ptfe_graphit]                          },\
                {0x0081,                [stainless_steel_316ti_316l]},\
                {0x0082,                [hastelloy_c276_steel_316ti]},\
                {0x0084,                [stainless_steel_316l_316ti]},\
                {0x0085,                [per_fluor_kautschuk]           },\
                {0x0086,                [stainless_steel_316l_b]        },\
                {0x0087,                [gold_stainless_steel_316l]     },\
                {0x0088,                [gold_plated_monel]                     },\
                {0x0089,                [pvdf]                                          },\
                {0x008A,                [epdm]                                          },\
                {0x00EA,                [ptfe_hastelloy]                        },\
                {0x00EB,                [stainless_steel_cf_8m]         },\
                {0x00EC,                [hastelloy_sst]                         },\
                {0x00ED,                [gold_plated_sst]                       },\
                {0x00EF,                [monel_400]                                     },\
                {0x00FA,                [not_used]                                      },\
                {0x00FB,                [none]                                          },\
                {0x00FC,                [unknown]                                       },\
                {0x00FD,                [special]                                       }\
}


#define DIFFERENTIAL_SENSOR trans1_sensor_type == 0x0012 || trans1_sensor_type == 0x0014 ||\
                                          trans1_sensor_type == 0x0016 ||  trans1_sensor_type == 0x001C\


#define STATIC_SENSOR trans1_sensor_type == 0x001E || trans1_sensor_type == 0x001F ||trans1_sensor_type == 0x0017 ||\
                                          trans1_sensor_type == 0x0020 || trans1_sensor_type == 0x0021 || trans1_sensor_type == 0x0023 || trans1_sensor_type == 0x0023

#define LIN_TABLE_USER  (trans1_lin_type == 1)

#define VALID_LIN_TABLE     \
IF (LIN_TABLE_USER)                     \
{                                                       \
        TRUE;                                   \
}                                                       \
ELSE                                            \
{                                                       \
        FALSE;                                  \
}

/*******************************************************************************/
/*****  MENU Bar  **************************************************************/
/*******************************************************************************/


#define EXTRA_ITEMS_DEVICE_MENU_SPECIALIST              MENU_Simulation,                        \
                                                        MENU_sensor_trim,                       \
                                                        OnlineDialog_position_corr,             \
                                                        OnlineDialog_set_lower_upper_value,     \
                                                        SEPARATOR,                              \                                                  \
                                                        OnlineDialog_reset_device,                     \
                                                        OnlineDialog_write_locking

#define EXTRA_ITEMS_VIEW_MENU_SPECIALIST                OnlineWindow_S_alarm,                   \
                                                        OnlineWindow_diagnosis,                 \
                                                        OnlineWindow_pressure_pointer,          \
                                                        OnlineDialog_selftest,                  \
                                                        OnlineWindow_about


#define EXTRA_ITEMS_VIEW_MENU_MAINTENANCE               OnlineWindow_M_alarm,                   \
                                                        OnlineWindow_about



#define YT1_LABEL       [trans_value]
#define YT1_VALUE       trans1_primary_value
#define YT1_LRV         func1_AI_pv_lower_range_value
#define YT1_URV         func1_AI_pv_upper_range_value


#define YT2_LABEL       [func_out_value]
#define YT2_VALUE       func1_AI_out_value
#define YT2_LRV         func1_AI_out_lower_range_value
#define YT2_URV         func1_AI_out_upper_range_value

/* Includes/*********************************************************************/

#include "SI_MainMenu.inc"
#include "SI_HlpM.inc"
#include "SI_FileM.inc"
#include "SI_DevM.inc"
#include "SI_ViewM.inc"
#include "SI_YT.inc"
#include "SIPAST_Macros_300.inc"

/************************************************************************************/
/*    IMPORT Transducer                                                                                                                         */
/************************************************************************************/
IMPORT "PDMTO2600-PA.inc"
{
        EVERYTHING;
        REDEFINITIONS
        {
                VARIABLE phys_install_date
                {
                   REDEFINE TYPE ASCII(16)
                   {
                        DEFAULT_VALUE "01.01.2003";
                   }
                }

                VARIABLE trans1_low_flow_cut_off
                {
                   REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE           0.0;
                                MIN_VALUE               0.0;
                                MAX_VALUE               15.0;
                        }
                }

                VARIABLE trans1_scale_out_upper_value
                {
                   REDEFINE TYPE  FLOAT
                   {
                        DEFAULT_VALUE 100.0;
                   }
                }

                VARIABLE func1_AI_pv_ftime
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE   0.0 ;
                                MIN_VALUE               0.0;
                                MAX_VALUE               60.0 ;
                        }
                }

                VARIABLE func1_AI_pv_upper_range_value
                {
                   REDEFINE TYPE  FLOAT
                   {
                        DEFAULT_VALUE 100.0;
                   }
                }

                VARIABLE func1_AI_out_upper_range_value
                {
                   REDEFINE TYPE  FLOAT
                   {
                        DEFAULT_VALUE 100.0;
                   }
                }

                VARIABLE func2_AI_pv_upper_range_value
                {
                   REDEFINE TYPE  FLOAT
                   {
                        DEFAULT_VALUE 411.0;
                   }
                }

                VARIABLE func2_AI_out_upper_range_value
                {
                   REDEFINE TYPE  FLOAT
                   {
                        DEFAULT_VALUE 100.0;
                   }
                }

                VARIABLE func2_AI_pv_ftime
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE   0.0 ;
                                MIN_VALUE               0.0;
                                MAX_VALUE               60.0 ;
                        }
                }

                VARIABLE trans1_flow_lin_sqrt_point
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  5.0;
                                MIN_VALUE          5.0;
                                MAX_VALUE          20.0;
                        }
                }

                VARIABLE func1_AI_lo_lo_lim
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  func1_AI_out_lower_range_value;
                        }
                }

                VARIABLE func2_AI_lo_lo_lim
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  func2_AI_out_lower_range_value;
                        }
                }

                VARIABLE func1_AI_lo_lim
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  func1_AI_out_lower_range_value;
                        }
                }

                VARIABLE func2_AI_lo_lim
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  func2_AI_out_lower_range_value;
                        }
                }

                VARIABLE func1_AI_hi_lim
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  func1_AI_out_upper_range_value;
                        }
                }

                VARIABLE func1_AI_hi_hi_lim
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  func1_AI_out_upper_range_value;
                        }
                }

                VARIABLE func2_AI_hi_lim
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  func2_AI_out_upper_range_value;
                        }
                }

                VARIABLE func2_AI_hi_hi_lim
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE  func2_AI_out_upper_range_value;
                        }
                }

                VARIABLE func1_AI_alarm_hys
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE 0.5 ;
                                MIN_VALUE 0.0 ;
                                MAX_VALUE 50.0 ;
                        }
                        ADD CONSTANT_UNIT "%";
                }

                VARIABLE func2_AI_alarm_hys
                {
                        REDEFINE TYPE   FLOAT
                        {
                                DEFAULT_VALUE 0.5 ;
                                MIN_VALUE 0.0 ;
                                MAX_VALUE 50.0 ;
                        }
                        ADD CONSTANT_UNIT "%";
                }

                VARIABLE trans1_sensor_high_limit
                {
                        REDEFINE HANDLING       READ & WRITE;
                        ADD POST_EDIT_ACTIONS
                        {
                                method_assignment2
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_assignment2
                        }

                }

                VARIABLE trans1_sensor_low_limit
                {
                        REDEFINE HANDLING       READ & WRITE;
                        ADD POST_EDIT_ACTIONS
                        {
                                method_assignment1
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_assignment1
                        }

                }

                VARIABLE trans1_sensor_unit
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE 1138;
                                DEF_TRANS_SENSOR_UNIT_CHANGE
                        }
                }

                VARIABLE trans1_tab_actual_number
                {
                        REDEFINE HANDLING       READ&WRITE;
                }

                VARIABLE phys_device_man_id
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE   DEFAULT_MANUFACTURER_ID ;
                          { 1,   [Acromag]                                              },
                          { 2,   [Allen_Bradley]                                },
                          { 3,   [Ametek]                                               },
                          { 4,   [Analog_Devices]                               },
                          { 5,   [Elsag_Bailey]                                 },
                          { 6,   [Beckman]                                              },
                          { 7,   [Bell_Microsensor]                             },
                          { 8,   [Bourns]                                               },
                          { 9,   [Bristol_Babcock]                              },
                          { 10,  [Brooks_Instrument]                    },
                          { 11,  [Chessell]                                             },
                          { 12,  [Combustion_Engineering]               },
                          { 13,  [Daniel_Industries]                    },
                          { 14,  [Delta]                                                },
                          { 15,  [Dieterich_Standard]                   },
                          { 16,  [Dohrmann]                                             },
                          { 17,  [Endress_and_Hauser]                   },
                          { 18,  [Elsag_Bailey]                                 },
                          { 19,  [Fisher_Controls]                              },
                          { 20,  [Foxboro]                                              },
                          { 21,  [Fuji]                                                 },
                          { 22,  [Elsag_Bailey]                                 },
                          { 23,  [Honeywell]                                    },
                          { 24,  [ITT_Barton]                                   },
                          { 25,  [KayRay_Sensall]                               },
                          { 26,  "ABB"                                                  },
                          { 27,  [Leeds_and_Northrup]                   },
                          { 28,  [Leslie]                                               },
                          { 29,  [M_System_Co]                                  },
                          { 30,  [Measurex]                                             },
                          { 31,  [Micro_Motion]                                 },
                          { 32,  [Moore_Industries]                             },
                          { 33,  [Moore_Products]                               },
                          { 34,  [Ohkura_Electric]                              },
                          { 35,  [Paine]                                                },
                          { 36,  [Rochester_Instrument_Systems] },
                          { 37,  [Ronan]                                                },
                          { 38,  [Rosemount]                                    },
                          { 39,  [Peek_Measurement]                             },
                          { 40,  [Schlumberger]                                 },
                          { 41,  [Sensall]                                              },
                          { 42,  [Siemens]                                              },
                          { 43,  [Camille_Bauer]                                },
                          { 44,  [Toshiba]                                              },
                          { 45,  [Transmation]                                  },
                          { 46,  [Rosemount_Analytical]                 },
                          { 47,  [Valmet]                                               },
                          { 48,  [Valtek]                                               },
                          { 49,  [Varec]                                                },
                          { 50,  [Viatran]                                              },
                          { 51,  [Weed]                                                 },
                          { 52,  [Westinghouse]                                 },
                          { 53,  [Xomox]                                                },
                          { 54,  [Yamatake]                                             },
                          { 55,  [Yokogawa]                                             },
                          { 56,  [Nuovo_Pignone]                                },
                          { 57,  [Promac]                                               },
                          { 58,  [Exac_Corporation]                             },
                          { 59,  [KDG_Mobrey]                                   },
                          { 60,  [Acrom_Control_System]                 },
                          { 61,  [Princo]                                               },
                          { 62,  [Smar]                                                 },
                          { 63,  [Foxboro_Eckardt]                              },
                          { 64,  [Measurement_Technology]               },
                          { 65,  [Applied_System_Technologies]  },
                          { 66,  [Samson]                                               },
                          { 67,  [Sparling_Instruments]                 },
                          { 68,  [Fireye]                                               },
                          { 69,  [Krohne]                                               },
                          { 70,  [Betz_Equipment]                               },
                          { 71,  [Druck]                                                },
                          { 72,  [SOR]                                                  },
                          { 73,  [Elcon_Instruments]                    },
                          { 74,  [EMCO]                                                 },
                          { 75,  [Termiflex]                                    },
                          { 76,  [VAF_Instruments]                              },
                          { 77,  [Westlock_Controls]                    },
                          { 78,  [Drexelbrook]                                  },
                          { 79,  [saab_tank_control]                    },
                          { 80,  [K_TEK]                                                },
                          { 81,  [Flowdata]                                             },
                          { 82,  [Draeger]                                              },
                          { 83,  [Raytek]                                               },
                          { 84,  [Meridian_Instruments]                 },
                          { 85,  [BTG]                                                  },
                          { 86,  [Magnetrol]                                    },
                          { 87,  [Neles_Controls]                               },
                          { 88,  [Milltronics]                                  },
                          { 89,  [HELIOS]                                               },
                          { 90,  [Anderson_Instrument_Company]  },
                          { 91,  [INOR]                                                 },
                          { 92,  [ROBERTSHAW]                                   },
                          { 93,  [PEPPERL_FUCHS]                                },
                          { 94,  [ACCUTECH]                                             },
                          { 95,  [Flow_Measurement]                             },
                          { 96,  [KAMSTRUP]                                             },
                          { 97,  [Knick]                                                },
                          { 98,  [VEGA]                                                 },
                          { 99,  [MTS_SYS_CORPS_SENSORS]                },
                          { 100, [Oval]                                                 },
                          { 101, [Masoneilan_DRESSER]                   },
                          { 102, [Besta]                                                },
                          { 103, [Ohmart]                                               },
                          { 104, [Harold_Beck_and_Sons]                 },
                          { 105, [rittmeyer_instrumentation]    },
                          { 106, [rossel_messtechnik]                   },
                          { 107, [WIKA]                                                 },
                          { 108, [Bopp_and_Reuther_Heinrichs]   },
                          { 109, [pr_eletronics]                                },
                          { 110, [jordan_controls]                              },
                          { 111, [valcom]                                               },
                          { 112, [us_electric_motors]                   },
                          { 113, [apparatebau_hundsbach]                },
                          { 250, [not_used]                                             },
                          { 251, [none]                                                 },
                          { 252, [unknown]                                              },
                          { 253, [special]                                              }
                        }
                }

                VARIABLE trans1_temperature_unit
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE   1001;
                                { 1000,  [unit_1000],           [unit_1000_help]}
                                { 1001,  [unit_1001],           [unit_1001_help]},
                                { 1002,  [unit_1002],           [unit_1002_help]},
                                { 1003,  [unit_1003],           [unit_1003_help]},
                                { 1342,  [unit_1342],           [unit_1342_help]},
                        }
                }

                VARIABLE trans1_primary_value_type
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE   0x0000;
                                {       0x0081,         [pv_type_mass_flow]                     },
                                {       0x0001,         [pv_type_volume_flow]           },
                                {       0x0082,         [pv_type_ave_mass_flow]         },
                                {       0x0083,         [pv_type_ave_volume_flow]       },
                                {       0x0084,         [pv_type_proc_temperature]      },
                                {       0x0085,         [pv_type_non_process_temp]      },
                                {       0x0086,         [pv_type_diff_temperature]      },
                                {       0x0000,         [pv_type_diff_pressure]         },
                                {       0x0087,         [pv_type_gauge_pressure]        },
                                {       0x0088,         [pv_type_absolute_pressure]     },
                                {       0x0002,         [pv_type_level]                         },
                                {       0x0089,         [pv_type_ph_value]                      },
                                {       0x008A,         [pv_type_milli_volts]           },
                                {       0x008B,         [pv_type_conductivity]          },
                                {       0x008C,         [pv_type_orp]                           },
                                {       0x0003,         [pv_type_volume]                        },
                                {       0xFFFF,         [pv_type_other]                         }
                        }
                }

                VARIABLE trans1_secondary_value_1_unit
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE   1138;
                                DEF_TRANS_SENSOR_UNIT_CHANGE
                        }
                        ADD POST_EDIT_ACTIONS
                        {
                                method_assignment_unit
                        }
                        ADD POST_READ_ACTIONS
                        {
                                method_assignment_unit
                        }


                }

                VARIABLE trans1_primary_value_unit
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE   1342;
                                UNIT_LIST
                        }

                }

                VARIABLE trans1_lin_type
                {
                        REDEFINE TYPE   ENUMERATED (1)
                        {
                                DEFAULT_VALUE   0x00;
                                {0x00,          [no_linearization]      },
                                {0x0A,          [sqr_root]                      },
                                {0xF1,          [sqr_root_3]            },
                                {0xF2,          [sqr_root_5]            },
                                {0x01,          [lin_curve]                     },
                                {0x15,          [cyl_tank]                      },
                                {0x14,          [spher_tank]            }
                        }
                }

                VARIABLE trans1_proc_conn_mat
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE   0x00FB;
                                DEF_TRANS_DIAPHRAGM_MAT
                        }
                }

                VARIABLE trans1_sens_fill_fluid
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEF_TRANS_SENS_FILL_FLUID
                        }
                }

                VARIABLE trans1_diaphragm_mat
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE   0x00FB;
                                DEF_TRANS_DIAPHRAGM_MAT
                        }
                }

                VARIABLE trans1_sensor_o_ring_mat
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEFAULT_VALUE   0x00FB;
                                DEF_TRANS_DIAPHRAGM_MAT
                        }
                        HANDLING        READ & WRITE;
                }

                VARIABLE phys_local_operation_enable
                {
                        REDEFINE TYPE   ENUMERATED (1)
                        {
                                DEFAULT_VALUE   1;
                                {       0,      [off]   },
                                {       1,      [on]    }
                        }
                }

                VARIABLE trans1_sensor_type
                {
                        REDEFINE TYPE   ENUMERATED (2)
                        {
                                DEF_TRANS_SENSOR_TYPE
                        }
                        HANDLING        READ;
                }

                VARIABLE trans1_sensor_high_limit
                {
                   REDEFINE TYPE  FLOAT
                        {
                                DEFAULT_VALUE   100.0;
                        }
                }

                VARIABLE trans1_scale_in_lower_value
                {
                   REDEFINE TYPE  FLOAT
                        {
                                DEFAULT_VALUE (trans1_local1);
                                // @@st riskant MIN_VALUE       (trans1_local1);
                                // @@st riskant MAX_VALUE       (trans1_local2);
                        }

                }

                VARIABLE trans1_scale_in_upper_value
                {
                   REDEFINE TYPE  FLOAT
                        {
                                DEFAULT_VALUE (trans1_local2);
                                // @@st riskant MIN_VALUE       (trans1_local1);
                                // @@st riskant MAX_VALUE       (trans1_local2);
                        }

                }

                VARIABLE trans1_tab_coordinate_number_loc
                {
                        REDEFINE TYPE   UNSIGNED_INTEGER(1)
                        {
                                DEFAULT_VALUE   0;
                                MIN_VALUE               0;
                                MAX_VALUE               20;
                        }
                }

                VARIABLE trans1_tab_y_value_0
                {
                        REDEFINE TYPE            FLOAT
                        {
                                DISPLAY_FORMAT "5.2f";
                                DEFAULT_VALUE   0.0;
                                MIN_VALUE       0.0;
                                MAX_VALUE       100.0;
                        }
                        REDEFINE CONSTANT_UNIT [Percent];
                }

                VARIABLE trans1_tab_y_value_1
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_2
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_3
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_4
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_5
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_6
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_7
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_8
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_9
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_10
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_11
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_12
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_13
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_14
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_15
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_16
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_17
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_18
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }
                VARIABLE trans1_tab_y_value_19
                {
                        REDEFINE TYPE FLOAT
                        {
                                REDEFINE DEFAULT_VALUE 0.0;
                        }
                }

                DELETE UNIT TB_SENSOR_UNIT;
        }
}

/*******************************************************************************/
/*****  Table: Specialist  *****************************************************/
/*******************************************************************************/

MENU Table_Main_Specialist
{
        LABEL   "2600T-263/265";
        ITEMS
        {
                Tab_s_ident,
                Tab_s_trans1
                Tab_s_output,
                Tab_s_const,
                Tab_s_interface_set,
                Tab_s_certificates
        }
}

MENU Tab_s_ident_device
{
        LABEL           [menu_ident_device];
        ITEMS
        {
                phys_device_man_id,
                phys_device_ser_num,
                phys_software_rev,
                phys_hardware_rev,
                phys_blk_profile_rev,
                phys_st_rev,
                phys_ident_number,
                phys_install_date,
                trans1_sensor_type,
                trans1_sensor_ser_num,
                phys_software_specifics,
                phys_hw_write_protection,
                phys_write_locking(READ_ONLY)

        }
}

MENU Tab_s_trans1_input_meassurelimit
{
        LABEL           [menu_input_measrange];
        ITEMS
        {
                trans1_sensor_unit,
                trans1_sensor_low_limit,
                trans1_sensor_high_limit,
                trans1_sensor_min_static_pres
                trans1_sensor_max_static_pres,
        }
}

MENU Tab_s_interface
{
        LABEL           [menu_human_interface];
        ITEMS
        {
                phys_local_operation_enable,
                phys_hw_write_protection,
                phys_meter_option
        }
}

MENU Tab_s_input_differentialpressure
{
        LABEL   IF (DIFFERENTIAL_SENSOR)
        {
                [menu_differentialpressure];
        }
        ELSE
        {
                [menu_static_pressure];
        }
        ITEMS
        {
                func1_AI_st_rev,
                func1_AI_out_unit,
                func1_AI_pv_ftime,
                Tab_s_func1_batch,
                Tab_s_func1_pv_range,
                Tab_s_func1_outscale,
                Tab_s_func1_limits,
                Tab_s_func1_interface
        }

}

MENU Tab_s_input_staticpressure
{
        LABEL           [menu_static_pressure];
        ITEMS
        {
                func2_AI_st_rev,
                func2_AI_out_unit,
                func2_AI_pv_ftime,
                Tab_s_func2_batch,
                Tab_s_func2_pv_range,
                Tab_s_func2_outscale,
                Tab_s_func2_limits,
                Tab_s_func2_interface
        }

        VALIDITY IF (DIFFERENTIAL_SENSOR)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_s_trans1_input_meassurerange
{
        LABEL           [menu_input_meassurerange];
        ITEMS
        {
                trans1_sensor_min_static_pres(HIDDEN),
                trans1_sensor_max_static_pres(HIDDEN),
                trans1_secondary_value_1_unit,
                trans1_scale_in_lower_value,
                trans1_scale_in_upper_value,
                trans1_sensor_low_limit(HIDDEN),
                trans1_sensor_high_limit(HIDDEN),
                IF (DIFFERENTIAL_SENSOR)
                        {
                                trans1_ptrbStaticPressureScaleInUnit,
                                trans1_ptrbstaticpressurescalein0,
                                trans1_ptrbstaticpressurescalein100
                        }
        }
}

MENU Tab_s_input_table
{
        LABEL           [menu_input_table];
        ITEMS
        {
                trans1_lin_type,
                trans1_low_flow_cut_off,
                trans1_flow_lin_sqrt_point,
                trans1_tab_actual_number (READ_ONLY)

        }
}

MENU Tab_s_output
{
        LABEL           [menu_output];
        ITEMS
        {
                Tab_s_input_differentialpressure,
                IF (DIFFERENTIAL_SENSOR)
                        {
                                Tab_s_input_staticpressure,
                        }
                Tab_s_interface
        }
}

MENU Tab_s_const
{
        LABEL           [menu_construct];
        ITEMS
        {
                Tab_s_const_design,
                Tab_s_const_proc
        }
}

MENU Tab_s_const_proc
{
        LABEL           [menu_const_proc];
        ITEMS
        {
                trans1_proc_conn_type,
                trans1_proc_conn_mat,
                trans1_Drain_Vent_Material_Code
        }
}

MENU Tab_s_const_design
{
        LABEL   [menu_const_design];
        ITEMS
        {
                Tab_s_const_design_sensor,
                Tab_s_const_remote_seal

        }
}

MENU Tab_s_const_design_sensor
{
        LABEL   [menu_const_design_sensor];
        ITEMS
        {
                trans1_sens_fill_fluid(READ_ONLY),
                trans1_diaphragm_mat(READ_ONLY),
                trans1_sensor_o_ring_mat
        }
}

MENU Tab_s_const_remote_seal
{
        LABEL           [remote_seal];
        ITEMS
        {
                trans1_ptrbNumberRemoteSeal,
                trans1_ptrbRemoteSealType,
                trans1_ptrbRemoteSealFillFluid,
                trans1_ptrbRemoteSealIsolatorMtl
        }
}

MENU Tab_s_interface_set
{
        LABEL           [menu_interface_set];
        ITEMS
        {
                // @@st DATE nur drei Byte trans1_ptrbsensorcaldate -> ASCII(7),
                trans1_ptrbsensorcalwho,
                trans1_ptrbTemperatureTrimValue
        }
}

MENU Tab_s_input_table_coordinate
{
        LABEL           [menu_coordinate];
        ITEMS
        {
                trans1_tab_coordinate_number_loc,
                trans1_tab_x_value_0,
                trans1_tab_y_value_0,
                trans1_tab_x_value_1,
                trans1_tab_y_value_1,
                trans1_tab_x_value_2,
                trans1_tab_y_value_2,
                trans1_tab_x_value_3,
                trans1_tab_y_value_3,
                trans1_tab_x_value_4,
                trans1_tab_y_value_4,
                trans1_tab_x_value_5,
                trans1_tab_y_value_5,
                trans1_tab_x_value_6,
                trans1_tab_y_value_6,
                trans1_tab_x_value_7,
                trans1_tab_y_value_7,
                trans1_tab_x_value_8,
                trans1_tab_y_value_8,
                trans1_tab_x_value_9,
                trans1_tab_y_value_9,
                trans1_tab_x_value_10,
                trans1_tab_y_value_10,
                trans1_tab_x_value_11,
                trans1_tab_y_value_11,
                trans1_tab_x_value_12,
                trans1_tab_y_value_12,
                trans1_tab_x_value_13,
                trans1_tab_y_value_13,
                trans1_tab_x_value_14,
                trans1_tab_y_value_14,
                trans1_tab_x_value_15,
                trans1_tab_y_value_15,
                trans1_tab_x_value_16,
                trans1_tab_y_value_16,
                trans1_tab_x_value_17,
                trans1_tab_y_value_17,
                trans1_tab_x_value_18,
                trans1_tab_y_value_18,
                trans1_tab_x_value_19,
                trans1_tab_y_value_19,
                trans1_tab_x_value_20,
                trans1_tab_y_value_20,

        }
        VALIDITY    VALID_LIN_TABLE
}
/*******************************************************************************/
/*****  Table: Maintenance  ****************************************************/
/*******************************************************************************/

MENU Table_Main_Maintenance
{
        LABEL   "2600T-263/265";
        ITEMS
        {
                Tab_m_ident,
                Tab_m_trans1,
                Tab_m_func1,
                Tab_m_const,
                Tab_m_interface_set,
                Tab_m_certificates
        }
}

MENU Tab_m_ident_device
{
        LABEL           [menu_ident_device];
        ITEMS
        {
                phys_device_man_id,
                phys_device_ser_num,
                phys_software_rev,
                phys_hardware_rev,
                phys_blk_profile_rev,
                phys_st_rev,
                phys_ident_number(READ_ONLY),
                phys_install_date(READ_ONLY),
                trans1_sensor_type,
                trans1_sensor_ser_num,
                phys_software_specifics,
                phys_hw_write_protection,
                phys_write_locking(READ_ONLY)

        }
}

MENU Tab_m_func1
{
        LABEL           [menu_output] ;
        ITEMS
        {
                Tab_m_input_differentialpressure,
                Tab_m_input_staticpressure
        }
}

MENU Tab_m_trans1_input_meassurelimit
{
        LABEL           [menu_input_measrange];
        ITEMS
        {
                trans1_ptrbCalUnit(READ_ONLY),
                trans1_sensor_low_limit(READ_ONLY),
                trans1_sensor_high_limit(READ_ONLY),
                trans1_sensor_min_static_pres(READ_ONLY)
                trans1_sensor_max_static_pres(READ_ONLY),
        }
}

MENU Tab_m_certificates
{
        LABEL           [menu_certificates];
        ITEMS
        {
                phys_device_certification       (READ_ONLY)
        }
}

MENU Tab_m_input_staticpressure
{
        LABEL           [menu_static_pressure];
        ITEMS
        {
                func2_AI_st_rev,
                func2_AI_out_unit(READ_ONLY),
                func2_AI_pv_ftime(READ_ONLY),
                Tab_m_func2_batch,
                Tab_m_func2_pv_range,
                Tab_m_func2_outscale,
                Tab_m_func2_limits,
                Tab_m_func2_interface
        }

        VALIDITY IF (DIFFERENTIAL_SENSOR)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }
}

MENU Tab_m_interface
{
        LABEL           [menu_human_interface];
        ITEMS
        {
                phys_local_operation_enable,
                phys_hw_write_protection,
                phys_meter_option
        }
}

MENU Tab_m_input_differentialpressure
{
        LABEL   IF (DIFFERENTIAL_SENSOR)
        {
                [menu_differentialpressure];
        }
        ELSE
        {
                [menu_static_pressure];
        }
        ITEMS
        {
                func1_AI_st_rev,
                func1_AI_out_unit(READ_ONLY),
                func1_AI_pv_ftime(READ_ONLY),
                Tab_m_func1_batch,
                Tab_m_func1_pv_range,
                Tab_m_func1_outscale,
                Tab_m_func1_limits,
                Tab_m_func1_interface
        }
}

MENU Tab_m_func1_interface
{
        LABEL           [menu_interface];
        ITEMS
        {
                func1_AI_out_decimal_point(READ_ONLY)
        }
}

MENU Tab_m_func2_interface
{
        LABEL           [menu_interface];
        ITEMS
        {
                func2_AI_out_decimal_point(READ_ONLY)
        }
}


MENU Tab_m_func1_batch
{
        LABEL           [menu_ident_batch_info];
        ITEMS
        {
                        func1_AI_batch_id(READ_ONLY),
                        func1_AI_batch_unit(READ_ONLY),
                        func1_AI_batch_operation(READ_ONLY),
                        func1_AI_batch_phase(READ_ONLY)
        }
}

MENU Tab_m_func2_batch
{
        LABEL           [menu_ident_batch_info];
        ITEMS
        {
                        func2_AI_batch_id(READ_ONLY),
                        func2_AI_batch_unit(READ_ONLY),
                        func2_AI_batch_operation(READ_ONLY),
                        func2_AI_batch_phase(READ_ONLY)
        }
}

MENU Tab_m_trans1_input_meassurerange
{
        LABEL           [menu_input_meassurerange];
        ITEMS
        {
                trans1_secondary_value_1_unit(READ_ONLY),
                trans1_scale_in_lower_value(READ_ONLY),
                trans1_scale_in_upper_value(READ_ONLY)
                trans1_sensor_low_limit(HIDDEN),
                trans1_sensor_high_limit(HIDDEN),
                IF (DIFFERENTIAL_SENSOR)
                        {
                                trans1_ptrbStaticPressureScaleInUnit,
                                trans1_ptrbstaticpressurescalein0,
                                trans1_ptrbstaticpressurescalein100
                        }
        }
}

MENU Tab_m_input_table
{
        LABEL           [menu_input_table];
        ITEMS
        {
                trans1_lin_type(READ_ONLY),
                trans1_low_flow_cut_off(READ_ONLY),
                trans1_flow_lin_sqrt_point(READ_ONLY),
                trans1_tab_actual_number (READ_ONLY)

        }
}

MENU Tab_m_const
{
        LABEL           [menu_construct];
        ITEMS
        {
                Tab_m_const_design,
                Tab_m_const_proc
        }
}

MENU Tab_m_const_proc
{
        LABEL           [menu_const_proc];
        ITEMS
        {
                trans1_proc_conn_type(READ_ONLY),
                trans1_proc_conn_mat(READ_ONLY),
                trans1_Drain_Vent_Material_Code(READ_ONLY)
        }
}

MENU Tab_m_const_design
{
        LABEL   [menu_const_design];
        ITEMS
        {
                Tab_m_const_design_sensor,
                Tab_m_const_remote_seal

        }
}

MENU Tab_m_const_design_sensor
{
        LABEL   [menu_const_design_sensor];
        ITEMS
        {
                trans1_sens_fill_fluid(READ_ONLY),
                trans1_diaphragm_mat(READ_ONLY),
                trans1_sensor_o_ring_mat(READ_ONLY)
        }
}

MENU Tab_m_const_remote_seal
{
        LABEL           [remote_seal];
        ITEMS
        {
                trans1_ptrbNumberRemoteSeal(READ_ONLY),
                trans1_ptrbRemoteSealType(READ_ONLY),
                trans1_ptrbRemoteSealFillFluid(READ_ONLY),
                trans1_ptrbRemoteSealIsolatorMtl(READ_ONLY)
        }
}

MENU Tab_m_interface_set
{
        LABEL           [menu_interface_set];
        ITEMS
        {
                // @@st DATE nur drei Byte trans1_ptrbsensorcaldate(READ_ONLY) -> ASCII(7),
                trans1_ptrbsensorcalwho(READ_ONLY),
                trans1_ptrbTemperatureTrimValue(READ_ONLY)
        }
}

/********************************************************************************/
/*Physical Block                                                                */
/********************************************************************************/
VARIABLE phys_software_rev_HART
{
        LABEL           [phys_software_revision];
        HELP            [phys_software_revision_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER(1) ;
        HANDLING        READ;
}

VARIABLE phys_software_specifics

{
        LABEL           [phys_software_specifics];
        HELP            [phys_software_specifics_help];
        CLASS           CONTAINED;
        TYPE            ASCII (1);
        HANDLING        READ;
}


VARIABLE phys_meter_option//pbMeterOption
{
        LABEL           [phys_display_source];
        HELP            [phys_display_source_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x01;
                {       0x01,   [out_aidp]      },
                {       0x02,   [percent]       }
//              {       0x03,   [current]       },
//              {       0x04,   [mass_flow]     },
//              {       0x05,   [vol_flow]      }
        }
        HANDLING        READ & WRITE;
}

VARIABLE phys_pbSelftest//pbSelftest
{
        LABEL           [selftest];
        HELP            [selftest_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x00;
                {       0x00,   [off]   },
                {       0x01,   [on]    },
        }
        HANDLING        READ & WRITE;
}

COMMAND read_phys_software_rev_HART
{
        BLOCK physical_block;
        INDEX 83;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        phys_software_rev_HART
                }
        }
}

COMMAND read_phys_pbSelftest
{
        BLOCK physical_block;
        INDEX 66;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        phys_pbSelftest
                }
        }
}

COMMAND write_phys_pbSelftest
{
        BLOCK physical_block;
        INDEX 66;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        phys_pbSelftest
                }
                REPLY
                {
                }
        }
}


COMMAND read_phys_software_specifics
{
        BLOCK physical_block;
        INDEX 108;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        phys_software_specifics //pbSoftwareSpecifics
                }
        }
}

COMMAND read_phys_meter_option//pbMeterOption
{
        BLOCK physical_block;
        INDEX 40;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        phys_meter_option//pbMeterOption
                }
        }
}

COMMAND write_phys_meter_option//pbMeterOption
{
        BLOCK physical_block;
        INDEX 40;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        phys_meter_option//pbMeterOption
                }
                REPLY
                {
                }
        }
}

/********************************************************************************/
/*Transducer Block                                                              */
/********************************************************************************/
VARIABLE trans1_ptrbStaticPressureValue
{
        LABEL           [trans_value];
        HELP            [trans_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}

VARIABLE trans1_ptrbStaticPressureValueStatus_quality
{
        LABEL           [status_quality];
        HELP            [value_status_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_OUTPUT_NO_RCAS
        }
        HANDLING        READ;
}

trans1_ptrbStaticPressureValueStatus_limit LIKE VARIABLE   trans1_ptrbStaticPressureValueStatus_quality
{
        REDEFINE LABEL          [status_limit];
        REDEFINE TYPE           ENUMERATED (1)
        {
                STATUS_OUTPUT_LIMIT
        }
}

VARIABLE trans1_sensor_min_static_pres//ptrbStaticPressureLoLim
{
        LABEL           [trans_sensor_min_static_pres];
        HELP            [trans_sensor_min_static_pres_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING        READ & WRITE;
        VALIDITY IF (DIFFERENTIAL_SENSOR)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }
        POST_EDIT_ACTIONS
        {
                method_edit_local_static_pressure_lower_range_value
        }
        POST_READ_ACTIONS
        {
                method_trans1_local_staticpressurescalein_range_min
        }

}

VARIABLE trans1_sensor_max_static_pres
{
        LABEL           [trans_sensor_max_static_pres];
        HELP            [trans_sensor_max_static_pres_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   411000.0;
        }
        HANDLING        READ & WRITE;
        VALIDITY IF (DIFFERENTIAL_SENSOR)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }
        POST_EDIT_ACTIONS
        {
                method_edit_local_static_pressure_upper_range_value
        }
        POST_READ_ACTIONS
        {
                method_trans1_local_staticpressurescalein_range_max
        }

}

VARIABLE trans1_set_lower_range_value//ptrbSetLowerRangeValue
{
        LABEL           [trans_set_lower_range_value];
        HELP            [trans_set_lower_range_value_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER(1);
        DEFAULT_VALUE 0;
        HANDLING        READ & WRITE;
}

VARIABLE trans1_set_upper_range_value//ptrbSetUpperRangeValue
{
        LABEL           [trans_set_upper_range_value];
        HELP            [trans_set_upper_range_value_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER(1);
        DEFAULT_VALUE 0;
        HANDLING        READ & WRITE;
}

VARIABLE trans1_ptrbStaticPressureScaleInUnit

{
        LABEL           [ptrbStaticPressureScaleInUnit];
        HELP            [ptrbStaticPressureScaleInUnit_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED(2)
        {
                DEFAULT_VALUE   1137;
                DEF_TRANS_SENSOR_UNIT_CHANGE
        }

        HANDLING        READ&WRITE;
        VALIDITY IF (DIFFERENTIAL_SENSOR)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }
        POST_EDIT_ACTIONS
        {
                method_assignment_trans1_ptrbStaticPressureScaleInUnit
        }

        POST_READ_ACTIONS
        {
                method_assignment_trans1_ptrbStaticPressureScaleInUnit
        }
}

VARIABLE trans1_ptrbstaticpressurescalein100
{
        LABEL   [ptrbstaticpressurescalein100];
        HELP    [ptrbstaticpressurescalein100_help];
        CLASS   CONTAINED;
        TYPE    FLOAT
        {
                DEFAULT_VALUE (trans1_local_staticpressurescalein_range_max);
                // @@st riskant MIN_VALUE       (trans1_local_staticpressurescalein_range_min);
                // @@st riskant MAX_VALUE       (trans1_local_staticpressurescalein_range_max);

                EDIT_FORMAT ".2f";
        }
        HANDLING READ & WRITE;
        VALIDITY IF (DIFFERENTIAL_SENSOR)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }

}

VARIABLE trans1_ptrbstaticpressurescalein0
{
        LABEL   [ptrbstaticpressurescalein0];
        HELP    [ptrbstaticpressurescalein0_help];
        CLASS   CONTAINED;
        TYPE    FLOAT
        {
                DEFAULT_VALUE (trans1_local_staticpressurescalein_range_min);
                // @@st riskant MIN_VALUE       (trans1_local_staticpressurescalein_range_min);
                // @@st riskant MAX_VALUE       (trans1_local_staticpressurescalein_range_max);
                EDIT_FORMAT ".2f";
        }

        HANDLING READ & WRITE;
        VALIDITY IF (DIFFERENTIAL_SENSOR)
        {
                TRUE;
        }
        ELSE
        {
                FALSE;
        }

}

VARIABLE trans1_ptrbNumberRemoteSeal
{
        LABEL           [ptrbNumberRemoteSeal];
        HELP            [ptrbNumberRemoteSeal_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER(1)
        {
                DEFAULT_VALUE   0x00;
                MIN_VALUE               0x00;
                MAX_VALUE               0x02;
        }

        HANDLING        READ&WRITE;
}

VARIABLE trans1_ptrbRemoteSealType
{
        LABEL           [ptrbRemoteSealType];
        HELP            [ptrbRemoteSealType_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER(1)
        {
                DEFAULT_VALUE   0xFB;
                {0x01,  "Flat diaphragm DN25"                                   },
                {0x02,  [flatdiaphragmansi1]                                    },
                {0x03,  [flatdiaphragmdn50]                                             },
                {0x04,  [flatdiaphragmansi2]                                    },
                {0x05,  [flatdiaphragmdn80]                                             },
                {0x06,  [flatdiaphragmansi3]                                    },
                {0x07,  "Tubus DN50"                                                    },
                {0x08,  "Tuus ANSI 2"                                                   },
                {0x09,  "Tubus DN80"                                                    },
                {0x0A,  "Tubus ANSI 3"                                                  },
                {0x0B,  "Rohrdruckfhler DN25/ANSI 1"                   },
                {0x0C,  "Rohrdruckfhler DN40/ANSI 1,5"                 },
                {0x0D,  "Rohrdruckfhler DN50/ANSI 2"                   },
                {0x0E,  "Rohrdruckfhler DN80/ANSI 3"                   },
                {0x0F,  "Druckfhler mit Nutberwurfmutter DN50"},
                {0x10,  "Druckfhler mit Clamp-Anschluss ANSI 2"},
                {0x11,  "Kleindruckfhler G 1 A"                                },
                {0x12,  "Kleindruckfhler G 1/2 A"                              },
                {0xFB,  [none]                                                                  },
                {0xFD,  [special]                                                               }

        }

        HANDLING        READ&WRITE;
}


VARIABLE trans1_ptrbRemoteSealFillFluid
{
        LABEL           [ptrbRemoteSealFillFluid];
        HELP            [ptrbRemoteSealFillFluid_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER(2)
        {
                DEF_TRANS_SENS_FILL_FLUID
        }

        HANDLING        READ&WRITE;
}

VARIABLE trans1_ptrbRemoteSealIsolatorMtl
{
    LABEL               [ptrbRemoteSealIsolatorMtl];
    HELP                [ptrbRemoteSealIsolatorMtl_help];
    CLASS INPUT;
    HANDLING READ & WRITE;
    TYPE ENUMERATED (2)
    {
                DEFAULT_VALUE   0x00FB;
                DEF_TRANS_DIAPHRAGM_MAT
        }
}

VARIABLE trans1_Drain_Vent_Material_Code
{
        LABEL   [trans_Drain_Vent_Material_Code];
        HELP    [trans_Drain_Vent_Material_Code_help];
        CLASS   CONTAINED;
        TYPE    ENUMERATED(2)
        {

                DEFAULT_VALUE   0x00FB;
                DEF_TRANS_DIAPHRAGM_MAT
        }
        HANDLING READ & WRITE;
}

VARIABLE trans1_ptrbsensorcaldate
{

                LABEL           [phys_cal_date];
                HELP            [phys_cal_date_help];
                CLASS           CONTAINED;
                TYPE            DATE;

                DEFAULT_VALUE   "01.01.2000";
                HANDLING READ & WRITE;
}

VARIABLE trans1_ptrbsensorcalwho
{
        LABEL           [phys_cal_who];
        HELP            [phys_cal_who_help];
        CLASS           CONTAINED;
        TYPE            ASCII (32);
        HANDLING        READ & WRITE;
}


VARIABLE trans1_ptrbSetSecondaryVariable1Zero
{
        LABEL   [trans_zero_adjustment];
        HELP    [trans_zero_adjustment_help];
        CLASS   CONTAINED;
        TYPE    UNSIGNED_INTEGER (1)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE trans1_ptrbTemperatureTrimValue
{
        LABEL   [sensor_temperature_trim];
        HELP    [sensor_temperature_trim_help];
        CLASS   CONTAINED;
        TYPE    FLOAT
        {
                DEFAULT_VALUE 0.0;
        }

        HANDLING READ & WRITE;
}

VARIABLE ptrbMaxStaticPressure
{
        LABEL           [static_pressure_hi_lim];
        HELP            [static_pressure_hi_lim_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE ptrbMinStaticPressure
{
        LABEL           [static_pressure_lo_lim];
        HELP            [static_pressure_lo_lim_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ & WRITE;
}

VARIABLE trans1_ptrbStaticPressureCalPointHi
{
        LABEL   [trans_cal_point_hi];
        HELP    [trans_cal_point_hi_help];
        CLASS   CONTAINED;
        TYPE    FLOAT
        {
                DEFAULT_VALUE -1e20;
        }

        HANDLING READ & WRITE;
}

VARIABLE trans1_ptrbTemperatureHiLimHys
{
        LABEL   "ptrbTemperatureHiLimHys";
        CLASS   CONTAINED;
        TYPE    FLOAT
        {
                DEFAULT_VALUE 88.5;
        }

        HANDLING READ ;
}

VARIABLE trans1_ptrbTemperatureLoLimHys
{
        LABEL   "ptrbTemperatureLoLimHys";
        CLASS   CONTAINED;
        TYPE    FLOAT
        {
                DEFAULT_VALUE -53.5;
        }

        HANDLING READ ;
}

VARIABLE trans1_ptrbStaticPressureCalPointLo
{
        LABEL   [trans_cal_point_lo];
        HELP    [trans_cal_point_lo_help];
        CLASS   CONTAINED;
        TYPE    FLOAT
        {
                DEFAULT_VALUE 0.0;
        }

        HANDLING READ & WRITE;
}

VARIABLE trans1_ptrbStaticPressureMinSpan
{
        LABEL   [trans_cal_min_span];
        HELP    [trans_cal_min_span_help];
        CLASS   CONTAINED;
        TYPE    FLOAT
        {
                DEFAULT_VALUE 1.0;
        }

        HANDLING READ;
}

VARIABLE trans1_ptrbCalUnit
{
        LABEL           [trans_pres_sensor_unit];
        HELP            [trans_pres_sensor_unit_help];
        CLASS           CONTAINED;
        TYPE ENUMERATED (2)
        {
                DEFAULT_VALUE   1138;
                DEF_TRANS_SENSOR_UNIT_CHANGE
        }

        HANDLING        READ & WRITE;
}

COMMAND read_trans1_ptrbCalUnit
{
        BLOCK transducer_block_1;
        INDEX 62;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbCalUnit
                }
        }
}

COMMAND write_trans1_ptrbCalUnit
{
        BLOCK transducer_block_1;
        INDEX 62;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbCalUnit
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbSetSecondaryVariable1Zero
{
        BLOCK transducer_block_1;
        INDEX 59;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbSetSecondaryVariable1Zero
                }
        }
}

COMMAND write_trans1_ptrbSetSecondaryVariable1Zero
{
        BLOCK transducer_block_1;
        INDEX 59;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbSetSecondaryVariable1Zero
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbsensorcaldate
{
        BLOCK   transducer_block_1;
        INDEX   69;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbsensorcaldate
                }
        }
}

COMMAND write_trans1_ptrbsensorcaldate
{
        BLOCK   transducer_block_1;
        INDEX   69;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbsensorcaldate
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbsensorcalwho
{
        BLOCK   transducer_block_1;
        INDEX   70;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbsensorcalwho
                }
        }
}

COMMAND write_trans1_ptrbsensorcalwho
{
        BLOCK   transducer_block_1;
        INDEX   70;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbsensorcalwho
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_Drain_Vent_Material_Code
{
        BLOCK   transducer_block_1;
        INDEX   72;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_Drain_Vent_Material_Code
                }
        }
}

COMMAND write_trans1_Drain_Vent_Material_Code
{
        BLOCK   transducer_block_1;
        INDEX   72;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_Drain_Vent_Material_Code
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbRemoteSealType
{
        BLOCK transducer_block_1;
        INDEX 73;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbRemoteSealType
                }
        }
}

COMMAND write_trans1_ptrbRemoteSealType
{
        BLOCK transducer_block_1;
        INDEX 73;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbRemoteSealType
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbNumberRemoteSeal
{
        BLOCK transducer_block_1;
        INDEX 74;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbNumberRemoteSeal
                }
        }
}

COMMAND write_trans1_ptrbNumberRemoteSeal
{
        BLOCK transducer_block_1;
        INDEX 74;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbNumberRemoteSeal
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbRemoteSealFillFluid
{
        BLOCK transducer_block_1;
        INDEX 75;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbRemoteSealFillFluid
                }
        }
}

COMMAND write_trans1_ptrbRemoteSealFillFluid
{
        BLOCK transducer_block_1;
        INDEX 75;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbRemoteSealFillFluid
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbRemoteSealIsolatorMtl
{
        BLOCK transducer_block_1;
        INDEX 76;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbRemoteSealIsolatorMtl
                }
        }
}

COMMAND write_trans1_ptrbRemoteSealIsolatorMtl
{
        BLOCK transducer_block_1;
        INDEX 76;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbRemoteSealIsolatorMtl
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbTemperatureTrimValue
{
        BLOCK   transducer_block_1;
        INDEX   77;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbTemperatureTrimValue
                }
        }
}

COMMAND write_trans1_ptrbTemperatureTrimValue
{
        BLOCK   transducer_block_1;
        INDEX   77;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbTemperatureTrimValue
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbStaticPressureValue
{
        BLOCK transducer_block_1;
        INDEX 82;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbStaticPressureValue,
                        trans1_ptrbStaticPressureValueStatus_quality <0xFC>,
                        trans1_ptrbStaticPressureValueStatus_limit<0x03>,
                }
        }
}

COMMAND read_trans1_set_lower_range_value
{
        BLOCK transducer_block_1;
        INDEX 84;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_set_lower_range_value
                }
        }
}

COMMAND write_trans1_set_lower_range_value
{
        BLOCK transducer_block_1;
        INDEX 84;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_set_lower_range_value
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_set_upper_range_value
{
        BLOCK transducer_block_1;
        INDEX 85;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_set_upper_range_value
                }
        }
}

COMMAND write_trans1_set_upper_range_value
{
        BLOCK transducer_block_1;
        INDEX 85;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_set_upper_range_value
                }
                REPLY
                {
                }
        }
}

COMMAND read_ptrbMaxStaticPressure
{
        BLOCK transducer_block_1;
        INDEX 100;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        ptrbMaxStaticPressure
                }
        }
}

COMMAND write_ptrbMaxStaticPressure
{
        BLOCK transducer_block_1;
        INDEX 100;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        ptrbMaxStaticPressure
                }
                REPLY
                {
                }
        }
}

COMMAND read_ptrbMinStaticPressure
{
        BLOCK transducer_block_1;
        INDEX 101;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        ptrbMinStaticPressure
                }
        }
}

COMMAND write_ptrbMinStaticPressure
{
        BLOCK transducer_block_1;
        INDEX 101;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        ptrbMinStaticPressure
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbStaticPressureCalPointHi
{
        BLOCK transducer_block_1;
        INDEX 210;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbStaticPressureCalPointHi
                }
        }
}

COMMAND write_trans1_ptrbStaticPressureCalPointHi
{
        BLOCK transducer_block_1;
        INDEX 210;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbStaticPressureCalPointHi
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbStaticPressureCalPointLo
{
        BLOCK transducer_block_1;
        INDEX 211;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbStaticPressureCalPointLo
                }
        }
}

COMMAND write_trans1_ptrbStaticPressureCalPointLo
{
        BLOCK transducer_block_1;
        INDEX 211;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbStaticPressureCalPointLo
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbStaticPressureMinSpan
{
        BLOCK transducer_block_1;
        INDEX 214;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbStaticPressureMinSpan
                }
        }
}

COMMAND write_trans1_ptrbStaticPressureMinSpan
{
        BLOCK transducer_block_1;
        INDEX 214;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbStaticPressureMinSpan
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_sensor_min_static_pres
{
        BLOCK transducer_block_1;
        INDEX 217;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_sensor_min_static_pres
                }
        }
}

COMMAND write_trans1_sensor_min_static_pres
{
        BLOCK transducer_block_1;
        INDEX 217;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_sensor_min_static_pres
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbStaticPressureScaleInUnit
{
        BLOCK transducer_block_1;
        INDEX 219;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbStaticPressureScaleInUnit
                }
        }
}

COMMAND write_trans1_ptrbStaticPressureScaleInUnit
{
        BLOCK transducer_block_1;
        INDEX 219;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbStaticPressureScaleInUnit
                }
                REPLY
                {
                }
        }
}

COMMAND read_ptrbstaticpressurescalein
{
        BLOCK transducer_block_1;
        INDEX 220;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbstaticpressurescalein100,trans1_ptrbstaticpressurescalein0
                }
        }
}

COMMAND write_ptrbstaticpressurescalein
{
        BLOCK transducer_block_1;
        INDEX 220;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        trans1_ptrbstaticpressurescalein100,trans1_ptrbstaticpressurescalein0
                }
                REPLY
                {
                }
        }
}

COMMAND read_trans1_ptrbTemperatureHiLimHys
{
        BLOCK transducer_block_1;
        INDEX 80;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbTemperatureHiLimHys
                }
        }
}

COMMAND read_trans1_ptrbTemperatureLoLimHys
{
        BLOCK transducer_block_1;
        INDEX 81;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        trans1_ptrbTemperatureLoLimHys
                }
        }
}

/*******************************************************************************/
/***** Function Block   ********************************************************/
/*******************************************************************************/
VARIABLE func1_aiDPXdScaleUnitFF
{
        LABEL           "";
        HELP            "";
        CLASS           CONTAINED;
        TYPE            ENUMERATED (2)
        {
                DEFAULT_VALUE   1137;
                DEF_TRANS_SENSOR_UNIT_CHANGE
        }
        HANDLING        READ & WRITE;
}

COMMAND read_func1_aiDPXdScaleUnitFF
{
        BLOCK function_block_1;
        INDEX 49;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        func1_aiDPXdScaleUnitFF
                }
        }
}

COMMAND write_func1_aiDPXdScaleUnitFF
{
        BLOCK function_block_1;
        INDEX 49;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        func1_aiDPXdScaleUnitFF
                }
                REPLY
                {
                }
        }
}

VARIABLE func2_aiPXdScaleUnitFF
{
        LABEL           "";
        HELP            "";
        CLASS           CONTAINED;
        TYPE            ENUMERATED (2)
        {
                DEFAULT_VALUE   1137;
                DEF_TRANS_SENSOR_UNIT_CHANGE
        }
        HANDLING        READ & WRITE;
}

COMMAND read_func2_aiPXdScaleUnitFF
{
        BLOCK function_block_2;
        INDEX 49;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        func2_aiPXdScaleUnitFF
                }
        }
}

COMMAND write_func2_aiPXdScaleUnitFF
{
        BLOCK function_block_2;
        INDEX 49;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        func2_aiPXdScaleUnitFF
                }
                REPLY
                {
                }
        }
}

/*******************************************************************************/
/***** Hilfsvariable ***********************************************************/
/*******************************************************************************/

VARIABLE pdm_revision
{
      CLASS LOCAL;
      LABEL [pdm_revision_label];
      TYPE ASCII(16)
      {
              DEFAULT_VALUE [edd_revision_label];
      }
}

/********************************************************************************/
/*    Unit relations                                                                                                                    */
/********************************************************************************/

// neu fr Messgrenzen
UNIT TB_MEASURING_UNIT
{
        trans1_sensor_unit:

        trans1_sensor_low_limit,
        trans1_sensor_high_limit,
        trans1_sensor_max_static_pres,
        trans1_sensor_min_static_pres,
}

UNIT TB_SENSOR_UNIT_CHANGE
{
        // sonst trans1_sensor_unit:
        trans1_ptrbCalUnit:

        trans1_cal_point_lo,
        trans1_cal_point_hi,
        trans1_cal_min_span,
        trans1_sensor_value,
        trans1_trimmed_value,
        trans1_ptrbStaticPressureCalPointLo,
        trans1_ptrbStaticPressureCalPointHi,
}

UNIT TB_SENSOR_PRESSURESCALEIN_UNIT
{
        trans1_ptrbStaticPressureScaleInUnit:

        trans1_ptrbstaticpressurescalein0,
        trans1_ptrbstaticpressurescalein100,
        ptrbMinStaticPressure,
        ptrbMaxStaticPressure,
        func2_AI_pv_lower_range_value,
        func2_AI_pv_upper_range_value,
        trans1_ptrbStaticPressureValue
}

UNIT TB_SENSOR_PRIMARY_VALUE_UNIT
{
        trans1_primary_value_unit:

        trans1_scale_out_lower_value,
        trans1_scale_out_upper_value,
        trans1_primary_value,

}

UNIT TB_SENSOR_PTRBTEMPERATURETRIMVALUE
{
        trans1_temperature_unit:

        trans1_ptrbTemperatureTrimValue
}

UNIT TRANS1_LOCAL_UNIT
{
        trans1_local_unit:

        trans1_local1,
        trans1_local2

}

UNIT TRANS1_PTRB_STATICPRESSURE_SCALEIN_UNI
{
        trans1_local_ptrbStaticPressureScaleInUnit:

        trans1_local_staticpressurescalein_range_min,
        trans1_local_staticpressurescalein_range_max

}

UNIT FUNC1_AIDPXDSCALEUNITFF
{
        trans1_primary_value_unit:

        func1_AI_pv_lower_range_value,
        func1_AI_pv_upper_range_value

}

UNIT FUNC2_AIDPXDSCALEUNITFF
{
        trans1_ptrbStaticPressureScaleInUnit:

        func2_AI_pv_lower_range_value,
        func2_AI_pv_upper_range_value

}

UNIT AI_1_OUT_SCALE_UNIT
{
        func1_AI_out_unit:

        func1_AI_out_value,
        func1_AI_out_upper_range_value,
        func1_AI_out_lower_range_value,
        func1_AI_hi_hi_lim,
        func1_AI_hi_lim,
        func1_AI_lo_lim,
        func1_AI_lo_lo_lim,
        func1_AI_hi_hi_alm_value,
        func1_AI_hi_alm_value,
        func1_AI_lo_alm_value,
        func1_AI_lo_lo_alm_value,
        func1_AI_FSafeValue
}

UNIT AI_2_OUT_SCALE_UNIT
{
        func2_AI_out_unit:

        func2_AI_out_value,
        func2_AI_out_upper_range_value,
        func2_AI_out_lower_range_value,
        func2_AI_hi_hi_lim,
        func2_AI_hi_lim,
        func2_AI_lo_lim,
        func2_AI_lo_lo_lim,
        func2_AI_hi_hi_alm_value,
        func2_AI_hi_alm_value,
        func2_AI_lo_alm_value,
        func2_AI_lo_lo_alm_value,
        func2_AI_FSafeValue
}

UNIT TRANS1_SECONDARY_VALUE_1_UNIT
{
        trans1_secondary_value_1_unit:

        trans1_min_sensor_value,
        trans1_max_sensor_value,
        trans1_sensor_value

}


/********************************************************************************/
/*Local Parameters                                                              */
/********************************************************************************/
VARIABLE trans1_local_unit
{
        CLASS   LOCAL;
        TYPE    ENUMERATED (2)
        {
                DEFAULT_VALUE   1138;
                DEF_TRANS_SENSOR_UNIT_CHANGE
        }

        HANDLING READ & WRITE;
}

VARIABLE trans1_local_ptrbStaticPressureScaleInUnit
{
        CLASS   LOCAL;
        TYPE   ENUMERATED(2)
        {
                DEFAULT_VALUE   1137;
                DEF_TRANS_SENSOR_UNIT_CHANGE
        }

        HANDLING READ & WRITE;
}

VARIABLE trans1_local1
{
        LABEL   "trans1_local1";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   0;
                EDIT_FORMAT ".2f";
        }

        HANDLING READ & WRITE;
}

VARIABLE trans1_local2
{
        LABEL   "trans1_local2";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   100;
                EDIT_FORMAT ".2f";
        }

        HANDLING READ & WRITE;
}

VARIABLE old_local_static_pressure_upper_range_value
{
        LABEL   "old_local_static_pressure_upper_range_value";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   100;
        }

        HANDLING READ & WRITE;
}

VARIABLE local_static_pressure_upper_range_value
{
        LABEL   "local_static_pressure_upper_range_value";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   100;
        }

        HANDLING READ & WRITE;
}

VARIABLE local_abort
{
        LABEL   "local_abort";
        CLASS   LOCAL;
        TYPE    INTEGER
        {
                DEFAULT_VALUE   0;
        }
}

VARIABLE old_local_static_pressure_lower_range_value
{
        LABEL   "old_local_static_pressure_lower_range_value";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   0;
        }

        HANDLING READ & WRITE;
}

VARIABLE local_static_pressure_lower_range_value
{
        LABEL   "local_static_pressure_lower_range_value";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   0;
        }

        HANDLING READ & WRITE;
}

VARIABLE trans1_local_staticpressurescalein_range_min
{
        LABEL   "trans1_local_staticpressurescalein_range_min";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   0;
                EDIT_FORMAT ".2f";
        }
        HANDLING READ & WRITE;
}

VARIABLE trans1_local_staticpressurescalein_range_max
{
        LABEL   "trans1_local_staticpressurescalein_range_max";
        CLASS   LOCAL;
        TYPE    FLOAT
        {
                DEFAULT_VALUE   411000;
                EDIT_FORMAT ".2f";
        }
        HANDLING READ & WRITE;
}

/*******************************************************************************/
/*****  Online-Dialogs  ********************************************************/
/*******************************************************************************/

MENU MENU_Simulation
{
        LABEL           [func_simulation_enabled];
        ITEMS
        {
                IF (DIFFERENTIAL_SENSOR)
                {
                        OnlineDialog_simulation_func1,
                        OnlineDialog_simulation_func2
                }
                ELSE
                {
                        OnlineDialog_simulation_func1
                }
        }
}

MENU OnlineDialog_simulation_func1
{
        LABEL       IF (DIFFERENTIAL_SENSOR)
                                {
                                        [Simulation_diff_absolute] ;
                                }
                                ELSE
                                {
                                        [Simulation_diff] ;
                                }
        ITEMS
        {
                Page_simulation_input_func1,
                Page_simulation_output_func1
        }
}

MENU OnlineDialog_simulation_func2
{
        LABEL           [Simulation_diff] ;
        ITEMS
        {
                        Page_simulation_input_func2,
                        Page_simulation_output_func2
        }
}

MENU MENU_sensor_trim
{
        LABEL           [menu_dialog_sensor_trim];
        ITEMS
        {
                IF(STATIC_SENSOR)
                {
                        OnlineDialog_sensor_trim_diff,
                }
                ELSE
                {
                        OnlineDialog_sensor_trim_diff,
                        OnlineDialog_sensor_trim_stat
                }
        }
}

MENU OnlineDialog_sensor_trim_diff
{
        LABEL       IF (STATIC_SENSOR)
                                {
                                        [menu_dialog_sensor_trim_stat_change];//[menu_dialog_sensor_trim_stat] ;
                                }
                                ELSE
                                {
                                        [menu_dialog_sensor_trim_diff] ;
                                }
        ITEMS
        {
                Page_cal_point_lo,
                Page_cal_point_hi,
                Page_date_person
        }
}

MENU Page_date_person
{
        LABEL           [menu_dialog_date_person];
        ITEMS
        {
                // @@st DATE nur drei Byte trans1_ptrbsensorcaldate -> ASCII(7),
                trans1_ptrbsensorcalwho
                method_set
        }
}

MENU OnlineDialog_sensor_trim_stat
{
        LABEL           [menu_dialog_sensor_trim_stat];
        ITEMS
        {
                Page_cal_point_lo_static,
                Page_cal_point_hi_static,
                Page_date_person
        }
}

MENU Page_cal_point_lo_static
{
        LABEL           [menu_dialog_sensor_trim_cal_point_lo];
        ITEMS
        {
                trans1_ptrbStaticPressureCalPointLo,
                trans1_ptrbStaticPressureMinSpan,
                trans1_ptrbStaticPressureValue,
                method_set
        }
}

MENU Page_cal_point_hi_static
{
        LABEL           [menu_dialog_sensor_trim_cal_point_hi];
        ITEMS
        {
                trans1_ptrbStaticPressureCalPointHi,
                trans1_ptrbStaticPressureMinSpan,
                trans1_ptrbStaticPressureValue,
                method_set
        }
}

MENU OnlineDialog_position_corr
{
        LABEL   [position_corr];
        HELP    [position_corr_help];
        ITEMS
        {
                Page_position_corr
        }
}

MENU Page_position_corr
{
        LABEL   [position_corr];
        HELP    [position_corr_help];
        ITEMS
        {
                trans1_secondary_value_1_value,
                method_position_corr
        }
}

MENU OnlineDialog_set_lower_upper_value
{
        LABEL   [set_lower_upper_value];
        ITEMS
        {
                Page_set_lower_value
                Page_set_upper_value
        }
}

MENU Page_set_lower_value
{
        LABEL   [func_lower_value];
        ITEMS
        {
                trans1_secondary_value_1_value,
                trans1_scale_in_lower_value(READ_ONLY),
                method_set_lower_range_value
        }
}

MENU Page_set_upper_value
{
        LABEL   [func_upper_value];
        ITEMS
        {
                trans1_secondary_value_1_value,
                trans1_scale_in_upper_value(READ_ONLY),
                method_set_upper_range_value
        }
}

MENU OnlineDialog_reset_device
{
        LABEL           [master_reset];
        HELP            [master_reset_help];
        ITEMS
        {
                Page_reset
        }
}



MENU Page_reset
{
        LABEL           [master_reset];
        HELP            [master_reset_help];
        ITEMS
        {
                phys_diagnosis,
                SEPARATOR,
                method_phys_factory_reset_params,
                method_phys_factory_reset_warm,
                method_phys_factory_reset_address
        }
}

MENU OnlineDialog_write_locking
{
        LABEL           [phys_write_locking];
        HELP            [phys_write_locking_help];
        ITEMS
        {
                phys_write_locking,
                phys_hw_write_protection,
                method_set
        }
}

MENU OnlineDialog_selftest
{
        LABEL           [selftest];
        HELP            [selftest_help];
        ITEMS
        {
                phys_diagnosis(READ_ONLY),
                method_selftest
        }
}

/*******************************************************************************/
/*****  Online-Windows  ********************************************************/
/*******************************************************************************/
MENU OnlineWindow_about
{
        LABEL           [onlinewindow_about_label];
        ITEMS
        {
                Page_about,
        }
}

MENU Page_about
{
        LABEL   [page_about_label];
        ITEMS
        {
                phys_device_id(READ_ONLY),
                trans1_sensor_type(READ_ONLY),
                phys_device_ser_num(READ_ONLY),
                trans1_sensor_ser_num(READ_ONLY),
                phys_software_rev(READ_ONLY),
                phys_hardware_rev(READ_ONLY),
                pdm_revision(READ_ONLY)
        }
}

MENU OnlineWindow_display
{
        LABEL           [menu_dialog_display];
        ITEMS
        {
                        IF (DIFFERENTIAL_SENSOR)
                        {
                                Page_display_func1,
                                Page_display_diff_pressure_value,
                                Page_display_func2,
                                Page_display_stat_pressure_value,
                        }
                        ELSE
                        {
                                Page_display_func1,
                                Page_display_static_pressure_value
                        }


        }
}

MENU Page_display_func1
{
        LABEL       IF (STATIC_SENSOR)
                                {
                                        [menu_static_pressure] ;
                                }
                                ELSE
                                {
                                        [menu_differentialpressure] ;
                                }
        ITEMS
        {
                BarVal_out_display_func1,
                Group_display_func1_out,
                Group_display_func1_in
        }
}

MENU Page_display_func2
{
        LABEL       [menu_static_pressure] ;
        ITEMS
        {
                BarVal_out_display_func2,
                Group_display_func2_out,
                Group_display_func2_in
        }
}

MENU Page_display_static_pressure_value
{
        LABEL           [display_static_pressure_value];
        ITEMS
        {
                BarVal_pv_display,
                Group_display_primary,
                Val_sensor_display,
                Group_display_secundary,
                Group_display_temperatur
        }

}

MENU Page_display_stat_pressure_value
{
        LABEL           [display_static_pressure_value];
        ITEMS
        {
                BarVal_pv_display_stat,
                Group_display_secundary_stat,
                Group_display_temperatur
        }

}

MENU Page_display_diff_pressure_value
{
        LABEL           [display_diff_pressure_value];
        ITEMS
        {
                BarVal_pv_display,
                Group_display_primary,
                Val_sensor_display,
                Group_display_secundary,
                Group_display_temperatur
        }
}

MENU Val_sensor_display
{
        LABEL           [trans_pres_sensor_value];
        ITEMS
        {
                trans1_sensor_value
        }
}

MENU BarVal_pv_display
{
        LABEL           [trans_value];
        ITEMS
        {
                trans1_primary_value,
                trans1_scale_out_lower_value(READ_ONLY),
                trans1_scale_out_upper_value(READ_ONLY),

        }
}

MENU Group_display_primary
{
        LABEL           [trans_value];
        ITEMS
        {
                trans1_primary_value,
                SEPARATOR,
                trans1_primary_value_status_quality,
                trans1_primary_value_status_limit
        }
}

MENU Group_display_secundary
{
        LABEL           [trans_secondary_value_1_value];
        ITEMS
        {
                trans1_secondary_value_1_value,
                SEPARATOR,
                trans1_secondary_value_1_status_quality,
                trans1_secondary_value_1_status_limit
        }
}

MENU BarVal_pv_display_stat
{
        LABEL           [trans_value];
        ITEMS
        {
                trans1_ptrbStaticPressureValue,
                trans1_ptrbstaticpressurescalein0(READ_ONLY),
                trans1_ptrbstaticpressurescalein100(READ_ONLY),

        }
}

MENU Group_display_primary_stat
{
        LABEL           [trans_value];
        ITEMS
        {
                trans1_primary_value,
                SEPARATOR,
                trans1_primary_value_status_quality,
                trans1_primary_value_status_limit
        }
}

MENU Val_sensor_display_stat
{
        LABEL           [trans_pres_sensor_value];
        ITEMS
        {
                trans1_ptrbStaticPressureValue
        }
}

MENU Group_display_secundary_stat
{
        LABEL           [trans_value];
        ITEMS
        {
                trans1_ptrbStaticPressureValue,
                SEPARATOR,
                trans1_ptrbStaticPressureValueStatus_quality,
                trans1_ptrbStaticPressureValueStatus_limit
        }
}

MENU OnlineWindow_diagnosis
{
        LABEL           [menu_dialog_diagnosis];
        ITEMS
        {
                Page_diagnosis_general,
                // @@st Page_diagnosis_phys_block,
                // Page_diagnosis_trans1_block,
                // Page_diagnosis_func1,
                // Page_diagnosis_func2
        }
}

MENU Page_diagnosis_general
{
        LABEL           [menu_dialog_general];
        ITEMS
        {
                phys_tag_desc(READ_ONLY),
                phys_device_man_id,
                phys_device_id,
                phys_device_ser_num,
                phys_software_rev,
                phys_hardware_rev,
                phys_install_date(READ_ONLY),
                phys_write_locking(READ_ONLY),
                phys_diagnosis,
        }
}

MENU Page_diagnosis_trans1_block
{
        LABEL           [trans1_block];
        ITEMS
        {
                trans1_blk_object,
                trans1_blk_parent_class,
                trans1_blk_class,
                trans1_blk_dd_reference,
                trans1_blk_dd_rev,
                trans1_blk_profile,
                trans1_blk_profile_rev,
                trans1_st_rev,
                trans1_actual_mode
        }
}

MENU OnlineWindow_pressure_pointer
{
        LABEL           [menu_indicator];
        ITEMS
        {
                // Quellen direkt eingebunden
                IF (DIFFERENTIAL_SENSOR)
                {
                        Page_pressure_pointer_diff,
                        Page_pressure_pointer_static,
                        Page_sens_temp_pointer,
                }
                ELSE
                {
                        Page_pressure_pointer_diff,
                        Page_sens_temp_pointer
                }
        }
}

MENU Page_pressure_pointer_diff
{
        LABEL       IF (STATIC_SENSOR)
                                {
                                        [menu_pres_indicator_static] ;
                                }
                                ELSE
                                {
                                        [menu_pres_indicator_diff] ;
                                }
        ITEMS
        {
                trans1_min_sensor_value(READ_ONLY),
                trans1_max_sensor_value(READ_ONLY),
                reset_pressure_pointer
        }
}

MENU Page_pressure_pointer_static
{
        LABEL           [menu_pres_indicator_static];
        ITEMS
        {
                ptrbMaxStaticPressure(READ_ONLY),
                ptrbMinStaticPressure(READ_ONLY),
                reset_pressure_pointer_static
        }
}

MENU OnlineWindow_S_alarm
{
        LABEL           [alarm_states];
        ITEMS
        {
                IF (DIFFERENTIAL_SENSOR)
                {
                        OnlineWindow_S_alarm_func1,
                        OnlineWindow_S_alarm_func2,
                }
                ELSE
                {
                        OnlineWindow_S_alarm_func1
                }

        }
}


MENU OnlineWindow_M_alarm
{
        LABEL           [alarm_states];
        ITEMS
        {
                IF (DIFFERENTIAL_SENSOR)
                {
                        OnlineWindow_M_alarm_func1,
                        OnlineWindow_M_alarm_func2,
                }
                ELSE
                {
                        OnlineWindow_M_alarm_func1
                }

        }
}

MENU OnlineWindow_S_alarm_func1
{
        LABEL       IF (STATIC_SENSOR)
                                {
                                        [menu_static_pressure] ;
                                }
                                ELSE
                                {
                                        [menu_differentialpressure] ;
                                }
        ITEMS
        {
                Page_alarm_overview_func1,
                Page_alarm_sum_func1,
        }
}

MENU OnlineWindow_M_alarm_func1
{
        LABEL       IF (STATIC_SENSOR)
                                {
                                        [menu_static_pressure] ;
                                }
                                ELSE
                                {
                                        [menu_differentialpressure] ;
                                }
        ITEMS
        {
                Page_alarm_overview_func1,
                Page_alarm_sum_func1,
        }
}

MENU OnlineWindow_S_alarm_func2
{
        LABEL           [menu_static_pressure] ;
        ITEMS
        {
                Page_alarm_overview_func2,
                Page_alarm_sum_func2,
        }
}

MENU OnlineWindow_M_alarm_func2
{
        LABEL           [menu_static_pressure] ;
        ITEMS
        {
                Page_alarm_overview_func2,
                Page_alarm_sum_func2,
        }
}

MENU Page_alarm_overview_func1
{
        LABEL [menu_dialog_overview] ;
        HELP  [dialog_alarm_overview_help] ;
        ITEMS
        {
                func1_AI_hi_hi_lim (READ_ONLY),
                func1_AI_hi_lim (READ_ONLY),
                func1_AI_lo_lim (READ_ONLY),
                func1_AI_lo_lo_lim (READ_ONLY),
        }
}

MENU Page_alarm_sum_func1
{
        LABEL           [menu_dialog_alarm_sum];
        ITEMS
        {
                func1_AI_current_state_alarm_sum,
                func1_AI_unacknowledged_state_alarm_sum,
        }
}

MENU Page_alarm_overview_func2
{
        LABEL [menu_dialog_overview] ;
        HELP  [dialog_alarm_overview_help] ;
        ITEMS
        {
                func2_AI_hi_hi_lim (READ_ONLY),
                func2_AI_hi_lim (READ_ONLY),
                func2_AI_lo_lim (READ_ONLY),
                func2_AI_lo_lo_lim (READ_ONLY),
        }
}

MENU Page_alarm_sum_func2
{
        LABEL           [menu_dialog_alarm_sum];
        ITEMS
        {
                func2_AI_current_state_alarm_sum,
                func2_AI_unacknowledged_state_alarm_sum,
        }
}

/*******************************************************************************/
/*****  Method  ****************************************************************/
/*******************************************************************************/

METHOD method_phys_factory_reset_params
{
        LABEL           [factory_reset_PARAMS];
        DEFINITION
        {
                int status;

                ACKNOWLEDGE([factory_reset_PARAMS]);

                phys_factory_reset = 1; //      [factory_reset_PARAMS]

                status = WriteCommand (write_phys_factory_reset);

                if ( status >= ID_FC_ERROR )
                {
                        ACKNOWLEDGE([DeviceWriteProtected]);
                        process_abort();
                }
        }
}


METHOD method_phys_factory_reset_warm
{
        LABEL           [phys_device_reset_cmd];
        DEFINITION
        {
                int status;
                char sz[512] ;
                int iLen ;

                ReadCommand (read_phys_write_locking);
                if ( phys_write_locking == 0 )
                        {
                                ACKNOWLEDGE([DeviceWriteProtected]);
                                process_abort();
                        }

                get_dictionary_string(phys_device_reset_cmd, sz, iLen) ;

                ACKNOWLEDGE(sz);

                phys_factory_reset = 2506 ;

                status = WriteCommand (write_phys_factory_reset);
        }
}


METHOD method_phys_factory_reset_address
{
        LABEL           [factory_reset_ADDRESS];
        DEFINITION
        {
                int status;
                char sz[512] ;
                int iLen ;

                ReadCommand (read_phys_write_locking);
                if ( phys_write_locking == 0 )
                        {
                                ACKNOWLEDGE([DeviceWriteProtected]);
                                process_abort();
                        }

                get_dictionary_string(factory_reset_ADDRESS, sz, iLen) ;

                ACKNOWLEDGE(sz);

                phys_factory_reset = 2712;

                status = WriteCommand (write_phys_factory_reset);
        }
}

METHOD  method_selftest
{
        LABEL   [selftest];
        DEFINITION
        {
                int ret;
                ret = ACKNOWLEDGE([acknowledge_selftest_start]);
                if (ret)
                {
                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        add_abort_method(abort_load_to_device);
                }

                ReadCommand (read_phys_write_locking);
                if ( phys_write_locking == 0 )
                        {
                                ACKNOWLEDGE([DeviceWriteProtected]);
                                process_abort();
                        }

                phys_pbSelftest = 1;
                status = WriteCommand (write_phys_pbSelftest);

                if ( status >= ID_FC_ERROR )
                {
                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        add_abort_method(abort_load_to_device);
                }

        }
}

METHOD method_position_corr
{
        LABEL   [start];
        CLASS INPUT;
        DEFINITION
        {
                        int status;
                        trans1_ptrbSetSecondaryVariable1Zero = 1;

                        status = WriteCommand (write_trans1_ptrbSetSecondaryVariable1Zero);

                        if ( status >= ID_FC_ERROR )
                        {
                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                add_abort_method(abort_load_to_device);
                        }
                        else
                        {
                                ACKNOWLEDGE([pos_correction_succeeded]);
                        }
        }
}

METHOD method_pre_download_dependencies
{
        DEFINITION
        {
                int status;

                status = ReadCommand (read_trans1_tab_actual_number);
        }
}

METHOD  method_assignment1
{
    DEFINITION
    {
                trans1_local_unit = trans1_sensor_unit;
                trans1_local1 = trans1_sensor_low_limit;
                trans1_local_unit = trans1_secondary_value_1_unit;
        }
}

METHOD  method_assignment2
{
    DEFINITION
    {
                trans1_local_unit = trans1_sensor_unit;
                trans1_local2 = trans1_sensor_high_limit;
                trans1_local_unit = trans1_secondary_value_1_unit;
        }
}

METHOD  method_trans1_local_staticpressurescalein_range_min
{
    DEFINITION
    {
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_sensor_unit;
                trans1_local_staticpressurescalein_range_min = trans1_sensor_min_static_pres;
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_ptrbStaticPressureScaleInUnit;
        }
}

METHOD  method_trans1_local_staticpressurescalein_range_max
{
    DEFINITION
    {
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_sensor_unit;
                trans1_local_staticpressurescalein_range_max = trans1_sensor_max_static_pres;
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_ptrbStaticPressureScaleInUnit;
        }
}

METHOD  method_assignment_unit
{
    DEFINITION
    {
                trans1_local_unit = trans1_secondary_value_1_unit;
        }
}

METHOD  method_assignment_trans1_ptrbStaticPressureScaleInUnit

{
    DEFINITION
    {
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_ptrbStaticPressureScaleInUnit;
        }
}

METHOD  method_set_lower_range_value
{
        LABEL   [trans_set_lower_range_value];
    DEFINITION
    {
                int status;
                        trans1_set_lower_range_value = 1;

                        status = WriteCommand (write_trans1_set_lower_range_value);

                        if ( status >= ID_FC_ERROR )
                        {
                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                add_abort_method(abort_load_to_device);
                        }
                        else
                        {
                                ACKNOWLEDGE([set_lower_range_value_successful]);
                        }
        }
}

METHOD  method_set_upper_range_value
{
        LABEL   [trans_set_upper_range_value];
    DEFINITION
    {
                int status;
                        trans1_set_upper_range_value = 1;

                        status = WriteCommand (write_trans1_set_upper_range_value);

                        if ( status >= ID_FC_ERROR )
                        {
                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                add_abort_method(abort_load_to_device);
                        }
                        else
                        {
                                ACKNOWLEDGE([set_upper_range_value_successful]);
                        }
        }
}

METHOD  method_pre_write_phys_write_locking
{
        LABEL   [method_pre_write_phys_write_locking];
    DEFINITION
    {
                        int ret;
                        long  ids[8];
                        add_abort_method(abort_load_to_device);
                        local_abort = 0; //kein Abbruch
                        ReadCommand (read_phys_write_locking);
                        if ( phys_write_locking == 0 )
                        {
                                ret = ACKNOWLEDGE([DeviceWriteProtected]);
                                if (ret) process_abort();
                        }
        }
}

METHOD  method_pre_read_sensor_low_high_limit
{
        LABEL   [pre_write_sensor_low_high_limit];
    DEFINITION
    {

                        ReadCommand (read_trans1_sensor_low_limit);
                        ReadCommand (read_trans1_sensor_high_limit);
                        if (trans1_sensor_low_limit != trans1_local1 )
                        {
                                 trans1_local1 = trans1_sensor_low_limit;
                        }
                        if (trans1_sensor_high_limit != trans1_local2 )
                        {
                                 trans1_local2 = trans1_sensor_high_limit;
                        }

        }
}

METHOD  method_pre_read_sensor_max_min_static_pres
{
        LABEL   [pre_write_sensor_low_high_limit];
    DEFINITION
    {
                        ReadCommand (read_trans1_ptrbStaticPressureScaleInUnit);
                        ReadCommand (read_trans1_sensor_min_static_pres);
                        ReadCommand (read_trans1_sensor_max_static_pres);
                        if (trans1_sensor_min_static_pres != trans1_local_staticpressurescalein_range_min )
                        {
                                 trans1_local_staticpressurescalein_range_min = trans1_sensor_min_static_pres;
                        }
                        if (trans1_sensor_max_static_pres != trans1_local_staticpressurescalein_range_max )
                        {
                                 trans1_local_staticpressurescalein_range_max = trans1_sensor_max_static_pres;
                        }

        }
}

METHOD  method_edit_local_static_pressure_lower_range_value
{
    DEFINITION
    {
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_sensor_unit;
                trans1_local_staticpressurescalein_range_min = trans1_sensor_min_static_pres;
                old_local_static_pressure_lower_range_value = trans1_sensor_min_static_pres;
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_ptrbStaticPressureScaleInUnit;
        }
}

METHOD  method_edit_local_static_pressure_upper_range_value
{
    DEFINITION
    {
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_sensor_unit;
                trans1_local_staticpressurescalein_range_max = trans1_sensor_max_static_pres;
                old_local_static_pressure_upper_range_value = trans1_sensor_max_static_pres;
                trans1_local_ptrbStaticPressureScaleInUnit = trans1_ptrbStaticPressureScaleInUnit;
        }
}

METHOD abort_load_to_device
{
        LABEL "aborting_return_to_normal";
        DEFINITION
        {
                local_abort=1;
                PUT_MESSAGE([Procedure_aborted]);
        }
}

METHOD reset_pressure_pointer_static
{
        LABEL   [reset];
        HELP    [reset_pres_pointer_Help];
        DEFINITION
        {
                int status;
                int choice_mode, choise_reset;

                ReadCommand (read_phys_write_locking);
                if ( phys_write_locking == 0 )
                        {
                                ACKNOWLEDGE([DeviceWriteProtected]);
                                process_abort();
                        }

                choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);

                choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);
                switch (choise_reset)
                {
                        case 0:
                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        break;
                        case 1:
                        switch (choice_mode)
                        {
                                case 0:
                                        status = WriteCommand(write_ptrbMaxStaticPressure);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_max_reset]);

                                break;
                                case 1:
                                        status = WriteCommand(write_ptrbMinStaticPressure);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_min_reset]);
                                break;
                                case 2:
                                        status = WriteCommand(write_ptrbMaxStaticPressure);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                        {
                                                status = WriteCommand(write_ptrbMinStaticPressure);
                                                if ( status >= ID_FC_ERROR )
                                                {
                                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                                                        process_abort();
                                                }
                                                else
                                                        ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);
                                        }
                                break;
                        }//switch (choice_mode)
                        break;
                }
        }
}

METHOD reset_pressure_pointer
{
        LABEL   [reset];
        HELP    [reset_pres_pointer_Help];
        DEFINITION
        {
                int status;
                int choice_mode, choise_reset;

                ReadCommand (read_phys_write_locking);
                if ( phys_write_locking == 0 )
                        {
                                ACKNOWLEDGE([DeviceWriteProtected]);
                                process_abort();
                        }

                choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);

                choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);
                switch (choise_reset)
                {
                        case 0:
                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        break;
                        case 1:
                        switch (choice_mode)
                        {
                                case 0:
                                        status = WriteCommand(write_trans1_max_sensor_value);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_max_reset]);

                                break;
                                case 1:
                                        status = WriteCommand(write_trans1_min_sensor_value);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_min_reset]);
                                break;
                                case 2:
                                        status = WriteCommand(write_trans1_max_sensor_value);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                        {
                                                status = WriteCommand(write_trans1_min_sensor_value);
                                                if ( status >= ID_FC_ERROR )
                                                {
                                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                                                        process_abort();
                                                }
                                                else
                                                        ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);
                                        }
                                break;
                        }//switch (choice_mode)
                        break;
                }
        }
}

METHOD reset_temperatur_pointer
{
        LABEL   [reset];
        HELP    [reset_temp_sens_pointer_Help];
        DEFINITION
        {
                int status;
                int choice_mode, choise_reset;

                ReadCommand (read_phys_write_locking);
                if ( phys_write_locking == 0 )
                        {
                                ACKNOWLEDGE([DeviceWriteProtected]);
                                process_abort();
                        }

                choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);

                choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);
                switch (choise_reset)
                {
                        case 0:
                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        break;
                        case 1:
                        switch (choice_mode)
                        {
                                case 0:
                                        status = WriteCommand(write_trans1_max_temperature);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_max_reset]);

                                break;
                                case 1:
                                        status = WriteCommand(write_trans1_min_temperature);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                                ACKNOWLEDGE([acknowledge_pointer_min_reset]);
                                break;
                                case 2:
                                        status = WriteCommand(write_trans1_max_temperature);
                                        if ( status >= ID_FC_ERROR )
                                        {
                                                ACKNOWLEDGE([acknowledge_process_aborted]);
                                                process_abort();
                                        }
                                        else
                                        {
                                                status = WriteCommand(write_trans1_min_temperature);
                                                if ( status >= ID_FC_ERROR )
                                                {
                                                        ACKNOWLEDGE([acknowledge_process_aborted]);
                                                        process_abort();
                                                }
                                                else
                                                        ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);
                                        }
                                break;
                        }//switch (choice_mode)
                        break;
                }
        }
}
/********************************************************************************/
/*      Download        LOAD TO PC                                                                                                              */
/********************************************************************************/

MENU download_variables
{
        LABEL           [menu_load_to_PC];
        PRE_READ_ACTIONS
        {
                method_pre_download_dependencies,
        }
        ITEMS
        {
                phys_tag_desc,
                phys_descriptor,
                phys_message,
                phys_device_man_id,
                phys_device_ser_num,
                phys_software_rev,
                phys_software_rev_HART,
                phys_hardware_rev,
                phys_blk_profile_rev,
                phys_st_rev,
                phys_ident_number,
                phys_install_date,
                phys_software_specifics,
                phys_hw_write_protection,
                phys_write_locking,
                phys_device_certification
                phys_local_operation_enable,
                phys_hw_write_protection,
                phys_meter_option,
                trans1_sensor_ser_num,
                trans1_sensor_type,
                trans1_st_rev,
                trans1_primary_value_type,
                trans1_sensor_unit,
                trans1_ptrbCalUnit,
                trans1_sensor_low_limit,
                trans1_sensor_high_limit,
                func1_aiDPXdScaleUnitFF,
                func2_aiPXdScaleUnitFF,
                IF(DIFFERENTIAL_SENSOR)
                        {
                                trans1_sensor_max_static_pres,
                                trans1_sensor_min_static_pres,
                                trans1_ptrbStaticPressureScaleInUnit,
                                trans1_ptrbstaticpressurescalein0,
                                trans1_ptrbstaticpressurescalein100,
                        }
                trans1_secondary_value_1_unit,
                trans1_scale_in_lower_value,
                trans1_scale_in_upper_value,
                trans1_primary_value_unit,
                trans1_scale_out_lower_value,
                trans1_scale_out_upper_value,
                trans1_low_flow_cut_off,
                trans1_flow_lin_sqrt_point,
                trans1_temperature_unit,
                trans1_sens_fill_fluid,
                trans1_diaphragm_mat,
                trans1_sensor_o_ring_mat,
                trans1_ptrbNumberRemoteSeal,
                trans1_ptrbRemoteSealType,
                trans1_ptrbRemoteSealFillFluid,
                trans1_ptrbRemoteSealIsolatorMtl,
                trans1_proc_conn_type,
                trans1_proc_conn_mat,
                trans1_Drain_Vent_Material_Code,
                // @@st DATE nur drei Byte trans1_ptrbsensorcaldate,
                trans1_ptrbsensorcalwho,
                trans1_ptrbTemperatureTrimValue,
                IF(DIFFERENTIAL_SENSOR)
                        {
                                func1_AI_st_rev
                                func1_AI_out_unit,
                                func1_AI_pv_ftime,
                                func1_AI_batch_id,
                                func1_AI_batch_unit,
                                func1_AI_batch_operation,
                                func1_AI_batch_phase,
                                func1_AI_pv_lower_range_value,
                                func1_AI_pv_upper_range_value,
                                func1_AI_out_lower_range_value,
                                func1_AI_out_upper_range_value,
                                func1_AI_lo_lo_lim,
                                func1_AI_lo_lim,
                                func1_AI_hi_lim,
                                func1_AI_hi_hi_lim,
                                func1_AI_alarm_hys,
                                func1_AI_out_decimal_point,
                                func2_AI_st_rev
                                func2_AI_out_unit,
                                func2_AI_pv_ftime,
                                func2_AI_batch_id,
                                func2_AI_batch_unit,
                                func2_AI_batch_operation,
                                func2_AI_batch_phase,
                                func2_AI_pv_lower_range_value,
                                func2_AI_pv_upper_range_value,
                                func2_AI_out_lower_range_value,
                                func2_AI_out_upper_range_value,
                                func2_AI_lo_lo_lim,
                                func2_AI_lo_lim,
                                func2_AI_hi_lim,
                                func2_AI_hi_hi_lim,
                                func2_AI_alarm_hys,
                                func2_AI_out_decimal_point
                                trans1_tab_actual_number,
                        }
                ELSE
                        {
                                func1_AI_out_unit,
                                func1_AI_pv_ftime,
                                func1_AI_batch_id,
                                func1_AI_batch_unit,
                                func1_AI_batch_operation,
                                func1_AI_batch_phase,
                                func1_AI_pv_lower_range_value,
                                func1_AI_pv_upper_range_value,
                                func1_AI_out_lower_range_value,
                                func1_AI_out_upper_range_value,
                                func1_AI_lo_lo_lim,
                                func1_AI_lo_lim,
                                func1_AI_hi_lim,
                                func1_AI_hi_hi_lim,
                                func1_AI_alarm_hys,
                                func1_AI_out_decimal_point,
                                trans1_tab_actual_number,
                        }
                trans1_lin_type,
                IF (trans1_lin_type == 0x01)
                {
                        IF (trans1_tab_actual_number > 0)
                        {
                                trans1_tab_x_value_0,
                                trans1_tab_y_value_0,
                        }
                        IF (trans1_tab_actual_number > 1)
                        {
                                trans1_tab_x_value_1,
                                trans1_tab_y_value_1,
                        }
                        IF (trans1_tab_actual_number > 2)
                        {
                                trans1_tab_x_value_2,
                                trans1_tab_y_value_2,
                        }
                        IF (trans1_tab_actual_number > 3)
                        {
                                trans1_tab_x_value_3,
                                trans1_tab_y_value_3,
                        }
                        IF (trans1_tab_actual_number > 4)
                        {
                                trans1_tab_x_value_4,
                                trans1_tab_y_value_4,
                        }
                        IF (trans1_tab_actual_number > 5)
                        {
                                trans1_tab_x_value_5,
                                trans1_tab_y_value_5,
                        }
                        IF (trans1_tab_actual_number > 6)
                        {
                                trans1_tab_x_value_6,
                                trans1_tab_y_value_6,
                        }
                        IF (trans1_tab_actual_number > 7)
                        {
                                trans1_tab_x_value_7,
                                trans1_tab_y_value_7,
                        }
                        IF (trans1_tab_actual_number > 8)
                        {
                                trans1_tab_x_value_8,
                                trans1_tab_y_value_8,
                        }
                        IF (trans1_tab_actual_number > 9)
                        {
                                trans1_tab_x_value_9,
                                trans1_tab_y_value_9,
                        }
                        IF (trans1_tab_actual_number > 10)
                        {
                                trans1_tab_x_value_10,
                                trans1_tab_y_value_10,
                        }
                        IF (trans1_tab_actual_number > 11)
                        {
                                trans1_tab_x_value_11,
                                trans1_tab_y_value_11,
                        }
                        IF (trans1_tab_actual_number > 12)
                        {
                                trans1_tab_x_value_12,
                                trans1_tab_y_value_12,
                        }
                        IF (trans1_tab_actual_number > 13)
                        {
                                trans1_tab_x_value_13,
                                trans1_tab_y_value_13,
                        }
                        IF (trans1_tab_actual_number > 14)
                        {
                                trans1_tab_x_value_14,
                                trans1_tab_y_value_14,
                        }
                        IF (trans1_tab_actual_number > 15)
                        {
                                trans1_tab_x_value_15,
                                trans1_tab_y_value_15,
                        }
                        IF (trans1_tab_actual_number > 16)
                        {
                                trans1_tab_x_value_16,
                                trans1_tab_y_value_16,
                        }
                        IF (trans1_tab_actual_number > 17)
                        {
                                trans1_tab_x_value_17,
                                trans1_tab_y_value_17,
                        }
                        IF (trans1_tab_actual_number > 18)
                        {
                                trans1_tab_x_value_18,
                                trans1_tab_y_value_18,
                        }
                        IF (trans1_tab_actual_number > 19)
                        {
                                trans1_tab_x_value_19,
                                trans1_tab_y_value_19,
                        }
                        IF (trans1_tab_actual_number > 20)
                        {
                                trans1_tab_x_value_20,
                                trans1_tab_y_value_20,
                        }

                }
        }
}

/********************************************************************************/
/*      Upload  LOAD TO DEVICE                                                                                                          */
/********************************************************************************/

MENU upload_variables
{
        LABEL           [menu_load_to_device];
        PRE_WRITE_ACTIONS
        {
                method_pre_write_phys_write_locking,
        }
        ITEMS
        {
                IF (local_abort == 0)
                {
                phys_tag_desc,
                phys_descriptor,
                phys_message,
                phys_ident_number,
                phys_install_date,
                phys_local_operation_enable,
                phys_meter_option,
                trans1_secondary_value_1_unit,
                trans1_scale_in_lower_value,
                trans1_scale_in_upper_value,
                IF(DIFFERENTIAL_SENSOR)
                        {
                                trans1_ptrbStaticPressureScaleInUnit,
                                trans1_ptrbstaticpressurescalein0,
                                trans1_ptrbstaticpressurescalein100,
                        }
                trans1_primary_value_unit,
                trans1_scale_out_lower_value,
                trans1_scale_out_upper_value,
                trans1_sensor_o_ring_mat,
                trans1_ptrbNumberRemoteSeal,
                trans1_ptrbRemoteSealType,
                trans1_ptrbRemoteSealFillFluid,
                trans1_ptrbRemoteSealIsolatorMtl,
                trans1_proc_conn_type,
                trans1_proc_conn_mat,
                trans1_Drain_Vent_Material_Code,
                trans1_ptrbsensorcalwho,
                trans1_primary_value_type,
                trans1_low_flow_cut_off,
                trans1_flow_lin_sqrt_point,
                trans1_temperature_unit,
                IF(DIFFERENTIAL_SENSOR)
                        {
                                func1_AI_out_unit,
                                func1_AI_pv_ftime,
                                func1_AI_batch_id,
                                func1_AI_batch_unit,
                                func1_AI_batch_operation,
                                func1_AI_batch_phase,
                                func1_AI_pv_lower_range_value,
                                func1_AI_pv_upper_range_value,
                                func1_AI_out_lower_range_value,
                                func1_AI_out_upper_range_value,
                                func1_AI_lo_lo_lim,
                                func1_AI_lo_lim,
                                func1_AI_hi_lim,
                                func1_AI_hi_hi_lim,
                                func1_AI_alarm_hys,
                                func1_AI_out_decimal_point,
                                func2_AI_out_unit,
                                func2_AI_pv_ftime,
                                func2_AI_batch_id,
                                func2_AI_batch_unit,
                                func2_AI_batch_operation,
                                func2_AI_batch_phase,
                                func2_AI_pv_lower_range_value,
                                func2_AI_pv_upper_range_value,
                                func2_AI_out_lower_range_value,
                                func2_AI_out_upper_range_value,
                                func2_AI_lo_lo_lim,
                                func2_AI_lo_lim,
                                func2_AI_hi_lim,
                                func2_AI_hi_hi_lim,
                                func2_AI_alarm_hys,
                                func2_AI_out_decimal_point,
                        }
                ELSE
                        {
                                func1_AI_out_unit,
                                func1_AI_pv_ftime,
                                func1_AI_batch_id,
                                func1_AI_batch_unit,
                                func1_AI_batch_operation,
                                func1_AI_batch_phase,
                                func1_AI_pv_lower_range_value,
                                func1_AI_pv_upper_range_value,
                                func1_AI_out_lower_range_value,
                                func1_AI_out_upper_range_value,
                                func1_AI_lo_lo_lim,
                                func1_AI_lo_lim,
                                func1_AI_hi_lim,
                                func1_AI_hi_hi_lim,
                                func1_AI_alarm_hys,
                                func1_AI_out_decimal_point,
                        }
                trans1_lin_type,
                IF (trans1_lin_type == 0x01)
                {
                        IF (trans1_tab_coordinate_number_loc > 0)
                        {
                                trans1_tab_x_value_0,
                                trans1_tab_y_value_0,
                        }
                        IF (trans1_tab_coordinate_number_loc > 1)
                        {
                                trans1_tab_x_value_1,
                                trans1_tab_y_value_1,
                        }
                        IF (trans1_tab_coordinate_number_loc > 2)
                        {
                                trans1_tab_x_value_2,
                                trans1_tab_y_value_2,
                        }
                        IF (trans1_tab_coordinate_number_loc > 3)
                        {
                                trans1_tab_x_value_3,
                                trans1_tab_y_value_3,
                        }
                        IF (trans1_tab_coordinate_number_loc > 4)
                        {
                                trans1_tab_x_value_4,
                                trans1_tab_y_value_4,
                        }
                        IF (trans1_tab_coordinate_number_loc > 5)
                        {
                                trans1_tab_x_value_5,
                                trans1_tab_y_value_5,
                        }
                        IF (trans1_tab_coordinate_number_loc > 6)
                        {
                                trans1_tab_x_value_6,
                                trans1_tab_y_value_6,
                        }
                        IF (trans1_tab_coordinate_number_loc > 7)
                        {
                                trans1_tab_x_value_7,
                                trans1_tab_y_value_7,
                        }
                        IF (trans1_tab_coordinate_number_loc > 8)
                        {
                                trans1_tab_x_value_8,
                                trans1_tab_y_value_8,
                        }
                        IF (trans1_tab_coordinate_number_loc > 9)
                        {
                                trans1_tab_x_value_9,
                                trans1_tab_y_value_9,
                        }
                        IF (trans1_tab_coordinate_number_loc > 10)
                        {
                                trans1_tab_x_value_10,
                                trans1_tab_y_value_10,
                        }
                        IF (trans1_tab_coordinate_number_loc > 11)
                        {
                                trans1_tab_x_value_11,
                                trans1_tab_y_value_11,
                        }
                        IF (trans1_tab_coordinate_number_loc > 12)
                        {
                                trans1_tab_x_value_12,
                                trans1_tab_y_value_12,
                        }
                        IF (trans1_tab_coordinate_number_loc > 13)
                        {
                                trans1_tab_x_value_13,
                                trans1_tab_y_value_13,
                        }
                        IF (trans1_tab_coordinate_number_loc > 14)
                        {
                                trans1_tab_x_value_14,
                                trans1_tab_y_value_14,
                        }
                        IF (trans1_tab_coordinate_number_loc > 15)
                        {
                                trans1_tab_x_value_15,
                                trans1_tab_y_value_15,
                        }
                        IF (trans1_tab_coordinate_number_loc > 16)
                        {
                                trans1_tab_x_value_16,
                                trans1_tab_y_value_16,
                        }
                        IF (trans1_tab_coordinate_number_loc > 17)
                        {
                                trans1_tab_x_value_17,
                                trans1_tab_y_value_17,
                        }
                        IF (trans1_tab_coordinate_number_loc > 18)
                        {
                                trans1_tab_x_value_18,
                                trans1_tab_y_value_18,
                        }
                        IF (trans1_tab_coordinate_number_loc > 19)
                        {
                                trans1_tab_x_value_19,
                                trans1_tab_y_value_19,
                        }
                        IF (trans1_tab_coordinate_number_loc > 20)
                        {
                                trans1_tab_x_value_20,
                                trans1_tab_y_value_20,
                        }
                }

          }
        }
}


